# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
#
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model
from msrest.exceptions import HttpOperationError


class Activity(Model):
    """An Activity is the basic communication type for the Bot Framework 3.0
    protocol.

    :param type: Contains the activity type. Possible values include:
     'message', 'contactRelationUpdate', 'conversationUpdate', 'typing',
     'endOfConversation', 'event', 'invoke', 'deleteUserData', 'messageUpdate',
     'messageDelete', 'installationUpdate', 'messageReaction', 'suggestion',
     'trace', 'handoff'
    :type type: str or ~botframework.connector.models.ActivityTypes
    :param id: Contains an ID that uniquely identifies the activity on the
     channel.
    :type id: str
    :param timestamp: Contains the date and time that the message was sent, in
     UTC, expressed in ISO-8601 format.
    :type timestamp: datetime
    :param local_timestamp: Contains the local date and time of the message
     expressed in ISO-8601 format.
     For example, 2016-09-23T13:07:49.4714686-07:00.
    :type local_timestamp: datetime
    :param local_timezone: Contains the name of the local timezone of the message,
     expressed in IANA Time Zone database format.
     For example, America/Los_Angeles.
    :type local_timezone: str
    :param service_url: Contains the URL that specifies the channel's service
     endpoint. Set by the channel.
    :type service_url: str
    :param channel_id: Contains an ID that uniquely identifies the channel.
     Set by the channel.
    :type channel_id: str
    :param from_property: Identifies the sender of the message.
    :type from_property: ~botframework.connector.models.ChannelAccount
    :param conversation: Identifies the conversation to which the activity
     belongs.
    :type conversation: ~botframework.connector.models.ConversationAccount
    :param recipient: Identifies the recipient of the message.
    :type recipient: ~botframework.connector.models.ChannelAccount
    :param text_format: Format of text fields Default:markdown. Possible
     values include: 'markdown', 'plain', 'xml'
    :type text_format: str or ~botframework.connector.models.TextFormatTypes
    :param attachment_layout: The layout hint for multiple attachments.
     Default: list. Possible values include: 'list', 'carousel'
    :type attachment_layout: str or
     ~botframework.connector.models.AttachmentLayoutTypes
    :param members_added: The collection of members added to the conversation.
    :type members_added: list[~botframework.connector.models.ChannelAccount]
    :param members_removed: The collection of members removed from the
     conversation.
    :type members_removed: list[~botframework.connector.models.ChannelAccount]
    :param reactions_added: The collection of reactions added to the
     conversation.
    :type reactions_added:
     list[~botframework.connector.models.MessageReaction]
    :param reactions_removed: The collection of reactions removed from the
     conversation.
    :type reactions_removed:
     list[~botframework.connector.models.MessageReaction]
    :param topic_name: The updated topic name of the conversation.
    :type topic_name: str
    :param history_disclosed: Indicates whether the prior history of the
     channel is disclosed.
    :type history_disclosed: bool
    :param locale: A locale name for the contents of the text field.
     The locale name is a combination of an ISO 639 two- or three-letter
     culture code associated with a language
     and an ISO 3166 two-letter subculture code associated with a country or
     region.
     The locale name can also correspond to a valid BCP-47 language tag.
    :type locale: str
    :param text: The text content of the message.
    :type text: str
    :param speak: The text to speak.
    :type speak: str
    :param input_hint: Indicates whether your bot is accepting,
     expecting, or ignoring user input after the message is delivered to the
     client. Possible values include: 'acceptingInput', 'ignoringInput',
     'expectingInput'
    :type input_hint: str or ~botframework.connector.models.InputHints
    :param summary: The text to display if the channel cannot render cards.
    :type summary: str
    :param suggested_actions: The suggested actions for the activity.
    :type suggested_actions: ~botframework.connector.models.SuggestedActions
    :param attachments: Attachments
    :type attachments: list[~botframework.connector.models.Attachment]
    :param entities: Represents the entities that were mentioned in the
     message.
    :type entities: list[~botframework.connector.models.Entity]
    :param channel_data: Contains channel-specific content.
    :type channel_data: object
    :param action: Indicates whether the recipient of a contactRelationUpdate
     was added or removed from the sender's contact list.
    :type action: str
    :param reply_to_id: Contains the ID of the message to which this message
     is a reply.
    :type reply_to_id: str
    :param label: A descriptive label for the activity.
    :type label: str
    :param value_type: The type of the activity's value object.
    :type value_type: str
    :param value: A value that is associated with the activity.
    :type value: object
    :param name: The name of the operation associated with an invoke or event
     activity.
    :type name: str
    :param relates_to: A reference to another conversation or activity.
    :type relates_to: ~botframework.connector.models.ConversationReference
    :param code: The a code for endOfConversation activities that indicates
     why the conversation ended. Possible values include: 'unknown',
     'completedSuccessfully', 'userCancelled', 'botTimedOut',
     'botIssuedInvalidMessage', 'channelFailed'
    :type code: str or ~botframework.connector.models.EndOfConversationCodes
    :param expiration: The time at which the activity should be considered to
     be "expired" and should not be presented to the recipient.
    :type expiration: datetime
    :param importance: The importance of the activity. Possible values
     include: 'low', 'normal', 'high'
    :type importance: str or ~botframework.connector.models.ActivityImportance
    :param delivery_mode: A delivery hint to signal to the recipient alternate
     delivery paths for the activity.
     The default delivery mode is "default". Possible values include: 'normal',
     'notification', 'expectReplies', 'ephemeral'
    :type delivery_mode: str or ~botframework.connector.models.DeliveryModes
    :param listen_for: List of phrases and references that speech and language
     priming systems should listen for
    :type listen_for: list[str]
    :param text_highlights: The collection of text fragments to highlight when
     the activity contains a ReplyToId value.
    :type text_highlights: list[~botframework.connector.models.TextHighlight]
    :param semantic_action: An optional programmatic action accompanying this
     request
    :type semantic_action: ~botframework.connector.models.SemanticAction
    :param caller_id: A string containing an IRI identifying the caller of a
     bot. This field is not intended to be transmitted over the wire, but is
     instead populated by bots and clients based on cryptographically
     verifiable data that asserts the identity of the callers (e.g. tokens).
    :type caller_id: str
    """

    _attribute_map = {
        "type": {"key": "type", "type": "str"},
        "id": {"key": "id", "type": "str"},
        "timestamp": {"key": "timestamp", "type": "iso-8601"},
        "local_timestamp": {"key": "localTimestamp", "type": "iso-8601"},
        "local_timezone": {"key": "localTimezone", "type": "str"},
        "service_url": {"key": "serviceUrl", "type": "str"},
        "channel_id": {"key": "channelId", "type": "str"},
        "from_property": {"key": "from", "type": "ChannelAccount"},
        "conversation": {"key": "conversation", "type": "ConversationAccount"},
        "recipient": {"key": "recipient", "type": "ChannelAccount"},
        "text_format": {"key": "textFormat", "type": "str"},
        "attachment_layout": {"key": "attachmentLayout", "type": "str"},
        "members_added": {"key": "membersAdded", "type": "[ChannelAccount]"},
        "members_removed": {"key": "membersRemoved", "type": "[ChannelAccount]"},
        "reactions_added": {"key": "reactionsAdded", "type": "[MessageReaction]"},
        "reactions_removed": {"key": "reactionsRemoved", "type": "[MessageReaction]"},
        "topic_name": {"key": "topicName", "type": "str"},
        "history_disclosed": {"key": "historyDisclosed", "type": "bool"},
        "locale": {"key": "locale", "type": "str"},
        "text": {"key": "text", "type": "str"},
        "speak": {"key": "speak", "type": "str"},
        "input_hint": {"key": "inputHint", "type": "str"},
        "summary": {"key": "summary", "type": "str"},
        "suggested_actions": {"key": "suggestedActions", "type": "SuggestedActions"},
        "attachments": {"key": "attachments", "type": "[Attachment]"},
        "entities": {"key": "entities", "type": "[Entity]"},
        "channel_data": {"key": "channelData", "type": "object"},
        "action": {"key": "action", "type": "str"},
        "reply_to_id": {"key": "replyToId", "type": "str"},
        "label": {"key": "label", "type": "str"},
        "value_type": {"key": "valueType", "type": "str"},
        "value": {"key": "value", "type": "object"},
        "name": {"key": "name", "type": "str"},
        "relates_to": {"key": "relatesTo", "type": "ConversationReference"},
        "code": {"key": "code", "type": "str"},
        "expiration": {"key": "expiration", "type": "iso-8601"},
        "importance": {"key": "importance", "type": "str"},
        "delivery_mode": {"key": "deliveryMode", "type": "str"},
        "listen_for": {"key": "listenFor", "type": "[str]"},
        "text_highlights": {"key": "textHighlights", "type": "[TextHighlight]"},
        "semantic_action": {"key": "semanticAction", "type": "SemanticAction"},
        "caller_id": {"key": "callerId", "type": "str"},
    }

    def __init__(self, **kwargs):
        super(Activity, self).__init__(**kwargs)
        self.type = kwargs.get("type", None)
        self.id = kwargs.get("id", None)
        self.timestamp = kwargs.get("timestamp", None)
        self.local_timestamp = kwargs.get("local_timestamp", None)
        self.local_timezone = kwargs.get("local_timezone", None)
        self.service_url = kwargs.get("service_url", None)
        self.channel_id = kwargs.get("channel_id", None)
        self.from_property = kwargs.get("from_property", None)
        self.conversation = kwargs.get("conversation", None)
        self.recipient = kwargs.get("recipient", None)
        self.text_format = kwargs.get("text_format", None)
        self.attachment_layout = kwargs.get("attachment_layout", None)
        self.members_added = kwargs.get("members_added", None)
        self.members_removed = kwargs.get("members_removed", None)
        self.reactions_added = kwargs.get("reactions_added", None)
        self.reactions_removed = kwargs.get("reactions_removed", None)
        self.topic_name = kwargs.get("topic_name", None)
        self.history_disclosed = kwargs.get("history_disclosed", None)
        self.locale = kwargs.get("locale", None)
        self.text = kwargs.get("text", None)
        self.speak = kwargs.get("speak", None)
        self.input_hint = kwargs.get("input_hint", None)
        self.summary = kwargs.get("summary", None)
        self.suggested_actions = kwargs.get("suggested_actions", None)
        self.attachments = kwargs.get("attachments", None)
        self.entities = kwargs.get("entities", None)
        self.channel_data = kwargs.get("channel_data", None)
        self.action = kwargs.get("action", None)
        self.reply_to_id = kwargs.get("reply_to_id", None)
        self.label = kwargs.get("label", None)
        self.value_type = kwargs.get("value_type", None)
        self.value = kwargs.get("value", None)
        self.name = kwargs.get("name", None)
        self.relates_to = kwargs.get("relates_to", None)
        self.code = kwargs.get("code", None)
        self.expiration = kwargs.get("expiration", None)
        self.importance = kwargs.get("importance", None)
        self.delivery_mode = kwargs.get("delivery_mode", None)
        self.listen_for = kwargs.get("listen_for", None)
        self.text_highlights = kwargs.get("text_highlights", None)
        self.semantic_action = kwargs.get("semantic_action", None)
        self.caller_id = kwargs.get("caller_id", None)


class AnimationCard(Model):
    """An animation card (Ex: gif or short video clip).

    :param title: Title of this card
    :type title: str
    :param subtitle: Subtitle of this card
    :type subtitle: str
    :param text: Text of this card
    :type text: str
    :param image: Thumbnail placeholder
    :type image: ~botframework.connector.models.ThumbnailUrl
    :param media: Media URLs for this card. When this field contains more than
     one URL, each URL is an alternative format of the same content.
    :type media: list[~botframework.connector.models.MediaUrl]
    :param buttons: Actions on this card
    :type buttons: list[~botframework.connector.models.CardAction]
    :param shareable: This content may be shared with others (default:true)
    :type shareable: bool
    :param autoloop: Should the client loop playback at end of content
     (default:true)
    :type autoloop: bool
    :param autostart: Should the client automatically start playback of media
     in this card (default:true)
    :type autostart: bool
    :param aspect: Aspect ratio of thumbnail/media placeholder. Allowed values
     are "16:9" and "4:3"
    :type aspect: str
    :param duration: Describes the length of the media content without
     requiring a receiver to open the content. Formatted as an ISO 8601
     Duration field.
    :type duration: str
    :param value: Supplementary parameter for this card
    :type value: object
    """

    _attribute_map = {
        "title": {"key": "title", "type": "str"},
        "subtitle": {"key": "subtitle", "type": "str"},
        "text": {"key": "text", "type": "str"},
        "image": {"key": "image", "type": "ThumbnailUrl"},
        "media": {"key": "media", "type": "[MediaUrl]"},
        "buttons": {"key": "buttons", "type": "[CardAction]"},
        "shareable": {"key": "shareable", "type": "bool"},
        "autoloop": {"key": "autoloop", "type": "bool"},
        "autostart": {"key": "autostart", "type": "bool"},
        "aspect": {"key": "aspect", "type": "str"},
        "duration": {"key": "duration", "type": "str"},
        "value": {"key": "value", "type": "object"},
    }

    def __init__(self, **kwargs):
        super(AnimationCard, self).__init__(**kwargs)
        self.title = kwargs.get("title", None)
        self.subtitle = kwargs.get("subtitle", None)
        self.text = kwargs.get("text", None)
        self.image = kwargs.get("image", None)
        self.media = kwargs.get("media", None)
        self.buttons = kwargs.get("buttons", None)
        self.shareable = kwargs.get("shareable", None)
        self.autoloop = kwargs.get("autoloop", None)
        self.autostart = kwargs.get("autostart", None)
        self.aspect = kwargs.get("aspect", None)
        self.duration = kwargs.get("duration", None)
        self.value = kwargs.get("value", None)


class Attachment(Model):
    """An attachment within an activity.

    :param content_type: mimetype/Contenttype for the file
    :type content_type: str
    :param content_url: Content Url
    :type content_url: str
    :param content: Embedded content
    :type content: object
    :param name: (OPTIONAL) The name of the attachment
    :type name: str
    :param thumbnail_url: (OPTIONAL) Thumbnail associated with attachment
    :type thumbnail_url: str
    """

    _attribute_map = {
        "content_type": {"key": "contentType", "type": "str"},
        "content_url": {"key": "contentUrl", "type": "str"},
        "content": {"key": "content", "type": "object"},
        "name": {"key": "name", "type": "str"},
        "thumbnail_url": {"key": "thumbnailUrl", "type": "str"},
    }

    def __init__(self, **kwargs):
        super(Attachment, self).__init__(**kwargs)
        self.content_type = kwargs.get("content_type", None)
        self.content_url = kwargs.get("content_url", None)
        self.content = kwargs.get("content", None)
        self.name = kwargs.get("name", None)
        self.thumbnail_url = kwargs.get("thumbnail_url", None)


class AttachmentData(Model):
    """Attachment data.

    :param type: Content-Type of the attachment
    :type type: str
    :param name: Name of the attachment
    :type name: str
    :param original_base64: Attachment content
    :type original_base64: bytearray
    :param thumbnail_base64: Attachment thumbnail
    :type thumbnail_base64: bytearray
    """

    _attribute_map = {
        "type": {"key": "type", "type": "str"},
        "name": {"key": "name", "type": "str"},
        "original_base64": {"key": "originalBase64", "type": "bytearray"},
        "thumbnail_base64": {"key": "thumbnailBase64", "type": "bytearray"},
    }

    def __init__(self, **kwargs):
        super(AttachmentData, self).__init__(**kwargs)
        self.type = kwargs.get("type", None)
        self.name = kwargs.get("name", None)
        self.original_base64 = kwargs.get("original_base64", None)
        self.thumbnail_base64 = kwargs.get("thumbnail_base64", None)


class AttachmentInfo(Model):
    """Metadata for an attachment.

    :param name: Name of the attachment
    :type name: str
    :param type: ContentType of the attachment
    :type type: str
    :param views: attachment views
    :type views: list[~botframework.connector.models.AttachmentView]
    """

    _attribute_map = {
        "name": {"key": "name", "type": "str"},
        "type": {"key": "type", "type": "str"},
        "views": {"key": "views", "type": "[AttachmentView]"},
    }

    def __init__(self, **kwargs):
        super(AttachmentInfo, self).__init__(**kwargs)
        self.name = kwargs.get("name", None)
        self.type = kwargs.get("type", None)
        self.views = kwargs.get("views", None)


class AttachmentView(Model):
    """Attachment View name and size.

    :param view_id: Id of the attachment
    :type view_id: str
    :param size: Size of the attachment
    :type size: int
    """

    _attribute_map = {
        "view_id": {"key": "viewId", "type": "str"},
        "size": {"key": "size", "type": "int"},
    }

    def __init__(self, **kwargs):
        super(AttachmentView, self).__init__(**kwargs)
        self.view_id = kwargs.get("view_id", None)
        self.size = kwargs.get("size", None)


class AudioCard(Model):
    """Audio card.

    :param title: Title of this card
    :type title: str
    :param subtitle: Subtitle of this card
    :type subtitle: str
    :param text: Text of this card
    :type text: str
    :param image: Thumbnail placeholder
    :type image: ~botframework.connector.models.ThumbnailUrl
    :param media: Media URLs for this card. When this field contains more than
     one URL, each URL is an alternative format of the same content.
    :type media: list[~botframework.connector.models.MediaUrl]
    :param buttons: Actions on this card
    :type buttons: list[~botframework.connector.models.CardAction]
    :param shareable: This content may be shared with others (default:true)
    :type shareable: bool
    :param autoloop: Should the client loop playback at end of content
     (default:true)
    :type autoloop: bool
    :param autostart: Should the client automatically start playback of media
     in this card (default:true)
    :type autostart: bool
    :param aspect: Aspect ratio of thumbnail/media placeholder. Allowed values
     are "16:9" and "4:3"
    :type aspect: str
    :param duration: Describes the length of the media content without
     requiring a receiver to open the content. Formatted as an ISO 8601
     Duration field.
    :type duration: str
    :param value: Supplementary parameter for this card
    :type value: object
    """

    _attribute_map = {
        "title": {"key": "title", "type": "str"},
        "subtitle": {"key": "subtitle", "type": "str"},
        "text": {"key": "text", "type": "str"},
        "image": {"key": "image", "type": "ThumbnailUrl"},
        "media": {"key": "media", "type": "[MediaUrl]"},
        "buttons": {"key": "buttons", "type": "[CardAction]"},
        "shareable": {"key": "shareable", "type": "bool"},
        "autoloop": {"key": "autoloop", "type": "bool"},
        "autostart": {"key": "autostart", "type": "bool"},
        "aspect": {"key": "aspect", "type": "str"},
        "duration": {"key": "duration", "type": "str"},
        "value": {"key": "value", "type": "object"},
    }

    def __init__(self, **kwargs):
        super(AudioCard, self).__init__(**kwargs)
        self.title = kwargs.get("title", None)
        self.subtitle = kwargs.get("subtitle", None)
        self.text = kwargs.get("text", None)
        self.image = kwargs.get("image", None)
        self.media = kwargs.get("media", None)
        self.buttons = kwargs.get("buttons", None)
        self.shareable = kwargs.get("shareable", None)
        self.autoloop = kwargs.get("autoloop", None)
        self.autostart = kwargs.get("autostart", None)
        self.aspect = kwargs.get("aspect", None)
        self.duration = kwargs.get("duration", None)
        self.value = kwargs.get("value", None)


class BasicCard(Model):
    """A basic card.

    :param title: Title of the card
    :type title: str
    :param subtitle: Subtitle of the card
    :type subtitle: str
    :param text: Text for the card
    :type text: str
    :param images: Array of images for the card
    :type images: list[~botframework.connector.models.CardImage]
    :param buttons: Set of actions applicable to the current card
    :type buttons: list[~botframework.connector.models.CardAction]
    :param tap: This action will be activated when user taps on the card
     itself
    :type tap: ~botframework.connector.models.CardAction
    """

    _attribute_map = {
        "title": {"key": "title", "type": "str"},
        "subtitle": {"key": "subtitle", "type": "str"},
        "text": {"key": "text", "type": "str"},
        "images": {"key": "images", "type": "[CardImage]"},
        "buttons": {"key": "buttons", "type": "[CardAction]"},
        "tap": {"key": "tap", "type": "CardAction"},
    }

    def __init__(self, **kwargs):
        super(BasicCard, self).__init__(**kwargs)
        self.title = kwargs.get("title", None)
        self.subtitle = kwargs.get("subtitle", None)
        self.text = kwargs.get("text", None)
        self.images = kwargs.get("images", None)
        self.buttons = kwargs.get("buttons", None)
        self.tap = kwargs.get("tap", None)


class CardAction(Model):
    """A clickable action.

    :param type: The type of action implemented by this button. Possible
     values include: 'openUrl', 'imBack', 'postBack', 'playAudio', 'playVideo',
     'showImage', 'downloadFile', 'signin', 'call', 'messageBack'
    :type type: str or ~botframework.connector.models.ActionTypes
    :param title: Text description which appears on the button
    :type title: str
    :param image: Image URL which will appear on the button, next to text
     label
    :type image: str
    :param text: Text for this action
    :type text: str
    :param display_text: (Optional) text to display in the chat feed if the
     button is clicked
    :type display_text: str
    :param value: Supplementary parameter for action. Content of this property
     depends on the ActionType
    :type value: object
    :param channel_data: Channel-specific data associated with this action
    :type channel_data: object
    """

    _attribute_map = {
        "type": {"key": "type", "type": "str"},
        "title": {"key": "title", "type": "str"},
        "image": {"key": "image", "type": "str"},
        "text": {"key": "text", "type": "str"},
        "display_text": {"key": "displayText", "type": "str"},
        "value": {"key": "value", "type": "object"},
        "channel_data": {"key": "channelData", "type": "object"},
    }

    def __init__(self, **kwargs):
        super(CardAction, self).__init__(**kwargs)
        self.type = kwargs.get("type", None)
        self.title = kwargs.get("title", None)
        self.image = kwargs.get("image", None)
        self.text = kwargs.get("text", None)
        self.display_text = kwargs.get("display_text", None)
        self.value = kwargs.get("value", None)
        self.channel_data = kwargs.get("channel_data", None)


class CardImage(Model):
    """An image on a card.

    :param url: URL thumbnail image for major content property
    :type url: str
    :param alt: Image description intended for screen readers
    :type alt: str
    :param tap: Action assigned to specific Attachment
    :type tap: ~botframework.connector.models.CardAction
    """

    _attribute_map = {
        "url": {"key": "url", "type": "str"},
        "alt": {"key": "alt", "type": "str"},
        "tap": {"key": "tap", "type": "CardAction"},
    }

    def __init__(self, **kwargs):
        super(CardImage, self).__init__(**kwargs)
        self.url = kwargs.get("url", None)
        self.alt = kwargs.get("alt", None)
        self.tap = kwargs.get("tap", None)


class ChannelAccount(Model):
    """Channel account information needed to route a message.

    :param id: Channel id for the user or bot on this channel (Example:
     joe@smith.com, or @joesmith or 123456)
    :type id: str
    :param name: Display friendly name
    :type name: str
    :param aad_object_id: This account's object ID within Azure Active
     Directory (AAD)
    :type aad_object_id: str
    :param role: Role of the entity behind the account (Example: User, Bot,
     etc.). Possible values include: 'user', 'bot'
    :type role: str or ~botframework.connector.models.RoleTypes
    """

    _attribute_map = {
        "id": {"key": "id", "type": "str"},
        "name": {"key": "name", "type": "str"},
        "aad_object_id": {"key": "aadObjectId", "type": "str"},
        "role": {"key": "role", "type": "str"},
    }

    def __init__(self, **kwargs):
        super(ChannelAccount, self).__init__(**kwargs)
        self.id = kwargs.get("id", None)
        self.name = kwargs.get("name", None)
        self.aad_object_id = kwargs.get("aadObjectId", None)
        self.role = kwargs.get("role", None)


class ConversationAccount(Model):
    """Conversation account represents the identity of the conversation within a channel.

    :param is_group: Indicates whether the conversation contains more than two
     participants at the time the activity was generated
    :type is_group: bool
    :param conversation_type: Indicates the type of the conversation in
     channels that distinguish between conversation types
    :type conversation_type: str
    :param id: Channel id for the user or bot on this channel (Example:
     joe@smith.com, or @joesmith or 123456)
    :type id: str
    :param name: Display friendly name
    :type name: str
    :param aad_object_id: This account's object ID within Azure Active
     Directory (AAD)
    :type aad_object_id: str
    :param role: Role of the entity behind the account (Example: User, Bot,
     etc.). Possible values include: 'user', 'bot'
    :type role: str or ~botframework.connector.models.RoleTypes
    :param tenant_id: This conversation's tenant ID
    :type tenant_id: str
    """

    _attribute_map = {
        "is_group": {"key": "isGroup", "type": "bool"},
        "conversation_type": {"key": "conversationType", "type": "str"},
        "id": {"key": "id", "type": "str"},
        "name": {"key": "name", "type": "str"},
        "aad_object_id": {"key": "aadObjectId", "type": "str"},
        "role": {"key": "role", "type": "str"},
        "tenant_id": {"key": "tenantID", "type": "str"},
    }

    def __init__(self, **kwargs):
        super(ConversationAccount, self).__init__(**kwargs)
        self.is_group = kwargs.get("is_group", None)
        self.conversation_type = kwargs.get("conversation_type", None)
        self.id = kwargs.get("id", None)
        self.name = kwargs.get("name", None)
        self.aad_object_id = kwargs.get("aad_object_id", None)
        self.role = kwargs.get("role", None)
        self.tenant_id = kwargs.get("tenant_id", None)


class ConversationMembers(Model):
    """Conversation and its members.

    :param id: Conversation ID
    :type id: str
    :param members: List of members in this conversation
    :type members: list[~botframework.connector.models.ChannelAccount]
    """

    _attribute_map = {
        "id": {"key": "id", "type": "str"},
        "members": {"key": "members", "type": "[ChannelAccount]"},
    }

    def __init__(self, **kwargs):
        super(ConversationMembers, self).__init__(**kwargs)
        self.id = kwargs.get("id", None)
        self.members = kwargs.get("members", None)


class ConversationParameters(Model):
    """Parameters for creating a new conversation.

    :param is_group: IsGroup
    :type is_group: bool
    :param bot: The bot address for this conversation
    :type bot: ~botframework.connector.models.ChannelAccount
    :param members: Members to add to the conversation
    :type members: list[~botframework.connector.models.ChannelAccount]
    :param topic_name: (Optional) Topic of the conversation (if supported by
     the channel)
    :type topic_name: str
    :param activity: (Optional) When creating a new conversation, use this
     activity as the initial message to the conversation
    :type activity: ~botframework.connector.models.Activity
    :param channel_data: Channel specific payload for creating the
     conversation
    :type channel_data: object
    :param tenant_id: (Optional) The tenant ID in which the conversation should be created
    :type tenant_id: str
    """

    _attribute_map = {
        "is_group": {"key": "isGroup", "type": "bool"},
        "bot": {"key": "bot", "type": "ChannelAccount"},
        "members": {"key": "members", "type": "[ChannelAccount]"},
        "topic_name": {"key": "topicName", "type": "str"},
        "activity": {"key": "activity", "type": "Activity"},
        "channel_data": {"key": "channelData", "type": "object"},
        "tenant_id": {"key": "tenantID", "type": "str"},
    }

    def __init__(self, **kwargs):
        super(ConversationParameters, self).__init__(**kwargs)
        self.is_group = kwargs.get("is_group", None)
        self.bot = kwargs.get("bot", None)
        self.members = kwargs.get("members", None)
        self.topic_name = kwargs.get("topic_name", None)
        self.activity = kwargs.get("activity", None)
        self.channel_data = kwargs.get("channel_data", None)
        self.tenant_id = kwargs.get("tenant_id", None)


class ConversationReference(Model):
    """An object relating to a particular point in a conversation.

    :param activity_id: (Optional) ID of the activity to refer to
    :type activity_id: str
    :param user: (Optional) User participating in this conversation
    :type user: ~botframework.connector.models.ChannelAccount
    :param bot: Bot participating in this conversation
    :type bot: ~botframework.connector.models.ChannelAccount
    :param conversation: Conversation reference
    :type conversation: ~botframework.connector.models.ConversationAccount
    :param channel_id: Channel ID
    :type channel_id: str
    :param locale: A locale name for the contents of the text field.
        The locale name is a combination of an ISO 639 two- or three-letter
        culture code associated with a language and an ISO 3166 two-letter
        subculture code associated with a country or region.
        The locale name can also correspond to a valid BCP-47 language tag.
    :type locale: str
    :param service_url: Service endpoint where operations concerning the
     referenced conversation may be performed
    :type service_url: str
    """

    _attribute_map = {
        "activity_id": {"key": "activityId", "type": "str"},
        "user": {"key": "user", "type": "ChannelAccount"},
        "bot": {"key": "bot", "type": "ChannelAccount"},
        "conversation": {"key": "conversation", "type": "ConversationAccount"},
        "channel_id": {"key": "channelId", "type": "str"},
        "locale": {"key": "locale", "type": "str"},
        "service_url": {"key": "serviceUrl", "type": "str"},
    }

    def __init__(self, **kwargs):
        super(ConversationReference, self).__init__(**kwargs)
        self.activity_id = kwargs.get("activity_id", None)
        self.user = kwargs.get("user", None)
        self.bot = kwargs.get("bot", None)
        self.conversation = kwargs.get("conversation", None)
        self.channel_id = kwargs.get("channel_id", None)
        self.locale = kwargs.get("locale", None)
        self.service_url = kwargs.get("service_url", None)


class ConversationResourceResponse(Model):
    """A response containing a resource.

    :param activity_id: ID of the Activity (if sent)
    :type activity_id: str
    :param service_url: Service endpoint where operations concerning the
     conversation may be performed
    :type service_url: str
    :param id: Id of the resource
    :type id: str
    """

    _attribute_map = {
        "activity_id": {"key": "activityId", "type": "str"},
        "service_url": {"key": "serviceUrl", "type": "str"},
        "id": {"key": "id", "type": "str"},
    }

    def __init__(self, **kwargs):
        super(ConversationResourceResponse, self).__init__(**kwargs)
        self.activity_id = kwargs.get("activity_id", None)
        self.service_url = kwargs.get("service_url", None)
        self.id = kwargs.get("id", None)


class ConversationsResult(Model):
    """Conversations result.

    :param continuation_token: Paging token
    :type continuation_token: str
    :param conversations: List of conversations
    :type conversations:
     list[~botframework.connector.models.ConversationMembers]
    """

    _attribute_map = {
        "continuation_token": {"key": "continuationToken", "type": "str"},
        "conversations": {"key": "conversations", "type": "[ConversationMembers]"},
    }

    def __init__(self, **kwargs):
        super(ConversationsResult, self).__init__(**kwargs)
        self.continuation_token = kwargs.get("continuation_token", None)
        self.conversations = kwargs.get("conversations", None)


class ExpectedReplies(Model):
    """ExpectedReplies.

    :param activities: A collection of Activities that conforms to the
     ExpectedReplies schema.
    :type activities: list[~botframework.connector.models.Activity]
    """

    _attribute_map = {"activities": {"key": "activities", "type": "[Activity]"}}

    def __init__(self, **kwargs):
        super(ExpectedReplies, self).__init__(**kwargs)
        self.activities = kwargs.get("activities", None)


class Entity(Model):
    """Metadata object pertaining to an activity.

    :param type: Type of this entity (RFC 3987 IRI)
    :type type: str
    """

    _attribute_map = {"type": {"key": "type", "type": "str"}}

    def __init__(self, **kwargs):
        super(Entity, self).__init__(**kwargs)
        self.type = kwargs.get("type", None)


class Error(Model):
    """Object representing error information.

    :param code: Error code
    :type code: str
    :param message: Error message
    :type message: str
    :param inner_http_error: Error from inner http call
    :type inner_http_error: ~botframework.connector.models.InnerHttpError
    """

    _attribute_map = {
        "code": {"key": "code", "type": "str"},
        "message": {"key": "message", "type": "str"},
        "inner_http_error": {"key": "innerHttpError", "type": "InnerHttpError"},
    }

    def __init__(self, **kwargs):
        super(Error, self).__init__(**kwargs)
        self.code = kwargs.get("code", None)
        self.message = kwargs.get("message", None)
        self.inner_http_error = kwargs.get("inner_http_error", None)


class ErrorResponse(Model):
    """An HTTP API response.

    :param error: Error message
    :type error: ~botframework.connector.models.Error
    """

    _attribute_map = {"error": {"key": "error", "type": "Error"}}

    def __init__(self, **kwargs):
        super(ErrorResponse, self).__init__(**kwargs)
        self.error = kwargs.get("error", None)


class ErrorResponseException(HttpOperationError):
    """Server responsed with exception of type: 'ErrorResponse'.

    :param deserialize: A deserializer
    :param response: Server response to be deserialized.
    """

    def __init__(self, deserialize, response, *args):

        super(ErrorResponseException, self).__init__(
            deserialize, response, "ErrorResponse", *args
        )


class Fact(Model):
    """Set of key-value pairs. Advantage of this section is that key and value
    properties will be
    rendered with default style information with some delimiter between them.
    So there is no need for developer to specify style information.

    :param key: The key for this Fact
    :type key: str
    :param value: The value for this Fact
    :type value: str
    """

    _attribute_map = {
        "key": {"key": "key", "type": "str"},
        "value": {"key": "value", "type": "str"},
    }

    def __init__(self, **kwargs):
        super(Fact, self).__init__(**kwargs)
        self.key = kwargs.get("key", None)
        self.value = kwargs.get("value", None)


class GeoCoordinates(Model):
    """GeoCoordinates (entity type: "https://schema.org/GeoCoordinates").

    :param elevation: Elevation of the location [WGS
     84](https://en.wikipedia.org/wiki/World_Geodetic_System)
    :type elevation: float
    :param latitude: Latitude of the location [WGS
     84](https://en.wikipedia.org/wiki/World_Geodetic_System)
    :type latitude: float
    :param longitude: Longitude of the location [WGS
     84](https://en.wikipedia.org/wiki/World_Geodetic_System)
    :type longitude: float
    :param type: The type of the thing
    :type type: str
    :param name: The name of the thing
    :type name: str
    """

    _attribute_map = {
        "elevation": {"key": "elevation", "type": "float"},
        "latitude": {"key": "latitude", "type": "float"},
        "longitude": {"key": "longitude", "type": "float"},
        "type": {"key": "type", "type": "str"},
        "name": {"key": "name", "type": "str"},
    }

    def __init__(self, **kwargs):
        super(GeoCoordinates, self).__init__(**kwargs)
        self.elevation = kwargs.get("elevation", None)
        self.latitude = kwargs.get("latitude", None)
        self.longitude = kwargs.get("longitude", None)
        self.type = kwargs.get("type", None)
        self.name = kwargs.get("name", None)


class HeroCard(Model):
    """A Hero card (card with a single, large image).

    :param title: Title of the card
    :type title: str
    :param subtitle: Subtitle of the card
    :type subtitle: str
    :param text: Text for the card
    :type text: str
    :param images: Array of images for the card
    :type images: list[~botframework.connector.models.CardImage]
    :param buttons: Set of actions applicable to the current card
    :type buttons: list[~botframework.connector.models.CardAction]
    :param tap: This action will be activated when user taps on the card
     itself
    :type tap: ~botframework.connector.models.CardAction
    """

    _attribute_map = {
        "title": {"key": "title", "type": "str"},
        "subtitle": {"key": "subtitle", "type": "str"},
        "text": {"key": "text", "type": "str"},
        "images": {"key": "images", "type": "[CardImage]"},
        "buttons": {"key": "buttons", "type": "[CardAction]"},
        "tap": {"key": "tap", "type": "CardAction"},
    }

    def __init__(self, **kwargs):
        super(HeroCard, self).__init__(**kwargs)
        self.title = kwargs.get("title", None)
        self.subtitle = kwargs.get("subtitle", None)
        self.text = kwargs.get("text", None)
        self.images = kwargs.get("images", None)
        self.buttons = kwargs.get("buttons", None)
        self.tap = kwargs.get("tap", None)


class InnerHttpError(Model):
    """Object representing inner http error.

    :param status_code: HttpStatusCode from failed request
    :type status_code: int
    :param body: Body from failed request
    :type body: object
    """

    _attribute_map = {
        "status_code": {"key": "statusCode", "type": "int"},
        "body": {"key": "body", "type": "object"},
    }

    def __init__(self, **kwargs):
        super(InnerHttpError, self).__init__(**kwargs)
        self.status_code = kwargs.get("status_code", None)
        self.body = kwargs.get("body", None)


class MediaCard(Model):
    """Media card.

    :param title: Title of this card
    :type title: str
    :param subtitle: Subtitle of this card
    :type subtitle: str
    :param text: Text of this card
    :type text: str
    :param image: Thumbnail placeholder
    :type image: ~botframework.connector.models.ThumbnailUrl
    :param media: Media URLs for this card. When this field contains more than
     one URL, each URL is an alternative format of the same content.
    :type media: list[~botframework.connector.models.MediaUrl]
    :param buttons: Actions on this card
    :type buttons: list[~botframework.connector.models.CardAction]
    :param shareable: This content may be shared with others (default:true)
    :type shareable: bool
    :param autoloop: Should the client loop playback at end of content
     (default:true)
    :type autoloop: bool
    :param autostart: Should the client automatically start playback of media
     in this card (default:true)
    :type autostart: bool
    :param aspect: Aspect ratio of thumbnail/media placeholder. Allowed values
     are "16:9" and "4:3"
    :type aspect: str
    :param duration: Describes the length of the media content without
     requiring a receiver to open the content. Formatted as an ISO 8601
     Duration field.
    :type duration: str
    :param value: Supplementary parameter for this card
    :type value: object
    """

    _attribute_map = {
        "title": {"key": "title", "type": "str"},
        "subtitle": {"key": "subtitle", "type": "str"},
        "text": {"key": "text", "type": "str"},
        "image": {"key": "image", "type": "ThumbnailUrl"},
        "media": {"key": "media", "type": "[MediaUrl]"},
        "buttons": {"key": "buttons", "type": "[CardAction]"},
        "shareable": {"key": "shareable", "type": "bool"},
        "autoloop": {"key": "autoloop", "type": "bool"},
        "autostart": {"key": "autostart", "type": "bool"},
        "aspect": {"key": "aspect", "type": "str"},
        "duration": {"key": "duration", "type": "str"},
        "value": {"key": "value", "type": "object"},
    }

    def __init__(self, **kwargs):
        super(MediaCard, self).__init__(**kwargs)
        self.title = kwargs.get("title", None)
        self.subtitle = kwargs.get("subtitle", None)
        self.text = kwargs.get("text", None)
        self.image = kwargs.get("image", None)
        self.media = kwargs.get("media", None)
        self.buttons = kwargs.get("buttons", None)
        self.shareable = kwargs.get("shareable", None)
        self.autoloop = kwargs.get("autoloop", None)
        self.autostart = kwargs.get("autostart", None)
        self.aspect = kwargs.get("aspect", None)
        self.duration = kwargs.get("duration", None)
        self.value = kwargs.get("value", None)


class MediaEventValue(Model):
    """Supplementary parameter for media events.

    :param card_value: Callback parameter specified in the Value field of the
     MediaCard that originated this event
    :type card_value: object
    """

    _attribute_map = {"card_value": {"key": "cardValue", "type": "object"}}

    def __init__(self, **kwargs):
        super(MediaEventValue, self).__init__(**kwargs)
        self.card_value = kwargs.get("card_value", None)


class MediaUrl(Model):
    """Media URL.

    :param url: Url for the media
    :type url: str
    :param profile: Optional profile hint to the client to differentiate
     multiple MediaUrl objects from each other
    :type profile: str
    """

    _attribute_map = {
        "url": {"key": "url", "type": "str"},
        "profile": {"key": "profile", "type": "str"},
    }

    def __init__(self, **kwargs):
        super(MediaUrl, self).__init__(**kwargs)
        self.url = kwargs.get("url", None)
        self.profile = kwargs.get("profile", None)


class Mention(Model):
    """Mention information (entity type: "mention").

    :param mentioned: The mentioned user
    :type mentioned: ~botframework.connector.models.ChannelAccount
    :param text: Sub Text which represents the mention (can be null or empty)
    :type text: str
    :param type: Type of this entity (RFC 3987 IRI)
    :type type: str
    """

    _attribute_map = {
        "mentioned": {"key": "mentioned", "type": "ChannelAccount"},
        "text": {"key": "text", "type": "str"},
        "type": {"key": "type", "type": "str"},
    }

    def __init__(self, **kwargs):
        super(Mention, self).__init__(**kwargs)
        self.mentioned = kwargs.get("mentioned", None)
        self.text = kwargs.get("text", None)
        self.type = kwargs.get("type", None)


class MessageReaction(Model):
    """Message reaction object.

    :param type: Message reaction type. Possible values include: 'like',
     'plusOne'
    :type type: str or ~botframework.connector.models.MessageReactionTypes
    """

    _attribute_map = {"type": {"key": "type", "type": "str"}}

    def __init__(self, **kwargs):
        super(MessageReaction, self).__init__(**kwargs)
        self.type = kwargs.get("type", None)


class OAuthCard(Model):
    """A card representing a request to perform a sign in via OAuth.

    :param text: Text for signin request
    :type text: str
    :param connection_name: The name of the registered connection
    :type connection_name: str
    :param buttons: Action to use to perform signin
    :type buttons: list[~botframework.connector.models.CardAction]
    """

    _attribute_map = {
        "text": {"key": "text", "type": "str"},
        "connection_name": {"key": "connectionName", "type": "str"},
        "buttons": {"key": "buttons", "type": "[CardAction]"},
    }

    def __init__(self, **kwargs):
        super(OAuthCard, self).__init__(**kwargs)
        self.text = kwargs.get("text", None)
        self.connection_name = kwargs.get("connection_name", None)
        self.buttons = kwargs.get("buttons", None)


class PagedMembersResult(Model):
    """Page of members.

    :param continuation_token: Paging token
    :type continuation_token: str
    :param members: The Channel Accounts.
    :type members: list[~botframework.connector.models.ChannelAccount]
    """

    _attribute_map = {
        "continuation_token": {"key": "continuationToken", "type": "str"},
        "members": {"key": "members", "type": "[ChannelAccount]"},
    }

    def __init__(self, **kwargs):
        super(PagedMembersResult, self).__init__(**kwargs)
        self.continuation_token = kwargs.get("continuation_token", None)
        self.members = kwargs.get("members", None)


class Place(Model):
    """Place (entity type: "https://schema.org/Place").

    :param address: Address of the place (may be `string` or complex object of
     type `PostalAddress`)
    :type address: object
    :param geo: Geo coordinates of the place (may be complex object of type
     `GeoCoordinates` or `GeoShape`)
    :type geo: object
    :param has_map: Map to the place (may be `string` (URL) or complex object
     of type `Map`)
    :type has_map: object
    :param type: The type of the thing
    :type type: str
    :param name: The name of the thing
    :type name: str
    """

    _attribute_map = {
        "address": {"key": "address", "type": "object"},
        "geo": {"key": "geo", "type": "object"},
        "has_map": {"key": "hasMap", "type": "object"},
        "type": {"key": "type", "type": "str"},
        "name": {"key": "name", "type": "str"},
    }

    def __init__(self, **kwargs):
        super(Place, self).__init__(**kwargs)
        self.address = kwargs.get("address", None)
        self.geo = kwargs.get("geo", None)
        self.has_map = kwargs.get("has_map", None)
        self.type = kwargs.get("type", None)
        self.name = kwargs.get("name", None)


class ReceiptCard(Model):
    """A receipt card.

    :param title: Title of the card
    :type title: str
    :param facts: Array of Fact objects
    :type facts: list[~botframework.connector.models.Fact]
    :param items: Array of Receipt Items
    :type items: list[~botframework.connector.models.ReceiptItem]
    :param tap: This action will be activated when user taps on the card
    :type tap: ~botframework.connector.models.CardAction
    :param total: Total amount of money paid (or to be paid)
    :type total: str
    :param tax: Total amount of tax paid (or to be paid)
    :type tax: str
    :param vat: Total amount of VAT paid (or to be paid)
    :type vat: str
    :param buttons: Set of actions applicable to the current card
    :type buttons: list[~botframework.connector.models.CardAction]
    """

    _attribute_map = {
        "title": {"key": "title", "type": "str"},
        "facts": {"key": "facts", "type": "[Fact]"},
        "items": {"key": "items", "type": "[ReceiptItem]"},
        "tap": {"key": "tap", "type": "CardAction"},
        "total": {"key": "total", "type": "str"},
        "tax": {"key": "tax", "type": "str"},
        "vat": {"key": "vat", "type": "str"},
        "buttons": {"key": "buttons", "type": "[CardAction]"},
    }

    def __init__(self, **kwargs):
        super(ReceiptCard, self).__init__(**kwargs)
        self.title = kwargs.get("title", None)
        self.facts = kwargs.get("facts", None)
        self.items = kwargs.get("items", None)
        self.tap = kwargs.get("tap", None)
        self.total = kwargs.get("total", None)
        self.tax = kwargs.get("tax", None)
        self.vat = kwargs.get("vat", None)
        self.buttons = kwargs.get("buttons", None)


class ReceiptItem(Model):
    """An item on a receipt card.

    :param title: Title of the Card
    :type title: str
    :param subtitle: Subtitle appears just below Title field, differs from
     Title in font styling only
    :type subtitle: str
    :param text: Text field appears just below subtitle, differs from Subtitle
     in font styling only
    :type text: str
    :param image: Image
    :type image: ~botframework.connector.models.CardImage
    :param price: Amount with currency
    :type price: str
    :param quantity: Number of items of given kind
    :type quantity: str
    :param tap: This action will be activated when user taps on the Item
     bubble.
    :type tap: ~botframework.connector.models.CardAction
    """

    _attribute_map = {
        "title": {"key": "title", "type": "str"},
        "subtitle": {"key": "subtitle", "type": "str"},
        "text": {"key": "text", "type": "str"},
        "image": {"key": "image", "type": "CardImage"},
        "price": {"key": "price", "type": "str"},
        "quantity": {"key": "quantity", "type": "str"},
        "tap": {"key": "tap", "type": "CardAction"},
    }

    def __init__(self, **kwargs):
        super(ReceiptItem, self).__init__(**kwargs)
        self.title = kwargs.get("title", None)
        self.subtitle = kwargs.get("subtitle", None)
        self.text = kwargs.get("text", None)
        self.image = kwargs.get("image", None)
        self.price = kwargs.get("price", None)
        self.quantity = kwargs.get("quantity", None)
        self.tap = kwargs.get("tap", None)


class ResourceResponse(Model):
    """A response containing a resource ID.

    :param id: Id of the resource
    :type id: str
    """

    _attribute_map = {"id": {"key": "id", "type": "str"}}

    def __init__(self, **kwargs):
        super(ResourceResponse, self).__init__(**kwargs)
        self.id = kwargs.get("id", None)


class SemanticAction(Model):
    """Represents a reference to a programmatic action.

    :param id: ID of this action
    :type id: str
    :param entities: Entities associated with this action
    :type entities: dict[str, ~botframework.connector.models.Entity]
    :param state: State of this action. Allowed values: `start`, `continue`, `done`
    :type state: str or ~botframework.connector.models.SemanticActionStates
    """

    _attribute_map = {
        "id": {"key": "id", "type": "str"},
        "entities": {"key": "entities", "type": "{Entity}"},
        "state": {"key": "state", "type": "str"},
    }

    def __init__(self, **kwargs):
        super(SemanticAction, self).__init__(**kwargs)
        self.id = kwargs.get("id", None)
        self.entities = kwargs.get("entities", None)
        self.state = kwargs.get("state", None)


class SigninCard(Model):
    """A card representing a request to sign in.

    :param text: Text for signin request
    :type text: str
    :param buttons: Action to use to perform signin
    :type buttons: list[~botframework.connector.models.CardAction]
    """

    _attribute_map = {
        "text": {"key": "text", "type": "str"},
        "buttons": {"key": "buttons", "type": "[CardAction]"},
    }

    def __init__(self, **kwargs):
        super(SigninCard, self).__init__(**kwargs)
        self.text = kwargs.get("text", None)
        self.buttons = kwargs.get("buttons", None)


class SuggestedActions(Model):
    """SuggestedActions that can be performed.

    :param to: Ids of the recipients that the actions should be shown to.
     These Ids are relative to the channelId and a subset of all recipients of
     the activity
    :type to: list[str]
    :param actions: Actions that can be shown to the user
    :type actions: list[~botframework.connector.models.CardAction]
    """

    _attribute_map = {
        "to": {"key": "to", "type": "[str]"},
        "actions": {"key": "actions", "type": "[CardAction]"},
    }

    def __init__(self, **kwargs):
        super(SuggestedActions, self).__init__(**kwargs)
        self.to = kwargs.get("to", None)
        self.actions = kwargs.get("actions", None)


class TextHighlight(Model):
    """Refers to a substring of content within another field.

    :param text: Defines the snippet of text to highlight
    :type text: str
    :param occurrence: Occurrence of the text field within the referenced
     text, if multiple exist.
    :type occurrence: int
    """

    _attribute_map = {
        "text": {"key": "text", "type": "str"},
        "occurrence": {"key": "occurrence", "type": "int"},
    }

    def __init__(self, **kwargs):
        super(TextHighlight, self).__init__(**kwargs)
        self.text = kwargs.get("text", None)
        self.occurrence = kwargs.get("occurrence", None)


class Thing(Model):
    """Thing (entity type: "https://schema.org/Thing").

    :param type: The type of the thing
    :type type: str
    :param name: The name of the thing
    :type name: str
    """

    _attribute_map = {
        "type": {"key": "type", "type": "str"},
        "name": {"key": "name", "type": "str"},
    }

    def __init__(self, **kwargs):
        super(Thing, self).__init__(**kwargs)
        self.type = kwargs.get("type", None)
        self.name = kwargs.get("name", None)


class ThumbnailCard(Model):
    """A thumbnail card (card with a single, small thumbnail image).

    :param title: Title of the card
    :type title: str
    :param subtitle: Subtitle of the card
    :type subtitle: str
    :param text: Text for the card
    :type text: str
    :param images: Array of images for the card
    :type images: list[~botframework.connector.models.CardImage]
    :param buttons: Set of actions applicable to the current card
    :type buttons: list[~botframework.connector.models.CardAction]
    :param tap: This action will be activated when user taps on the card
     itself
    :type tap: ~botframework.connector.models.CardAction
    """

    _attribute_map = {
        "title": {"key": "title", "type": "str"},
        "subtitle": {"key": "subtitle", "type": "str"},
        "text": {"key": "text", "type": "str"},
        "images": {"key": "images", "type": "[CardImage]"},
        "buttons": {"key": "buttons", "type": "[CardAction]"},
        "tap": {"key": "tap", "type": "CardAction"},
    }

    def __init__(self, **kwargs):
        super(ThumbnailCard, self).__init__(**kwargs)
        self.title = kwargs.get("title", None)
        self.subtitle = kwargs.get("subtitle", None)
        self.text = kwargs.get("text", None)
        self.images = kwargs.get("images", None)
        self.buttons = kwargs.get("buttons", None)
        self.tap = kwargs.get("tap", None)


class ThumbnailUrl(Model):
    """Thumbnail URL.

    :param url: URL pointing to the thumbnail to use for media content
    :type url: str
    :param alt: HTML alt text to include on this thumbnail image
    :type alt: str
    """

    _attribute_map = {
        "url": {"key": "url", "type": "str"},
        "alt": {"key": "alt", "type": "str"},
    }

    def __init__(self, **kwargs):
        super(ThumbnailUrl, self).__init__(**kwargs)
        self.url = kwargs.get("url", None)
        self.alt = kwargs.get("alt", None)


class TokenRequest(Model):
    """A request to receive a user token.

    :param provider: The provider to request a user token from
    :type provider: str
    :param settings: A collection of settings for the specific provider for
     this request
    :type settings: dict[str, object]
    """

    _attribute_map = {
        "provider": {"key": "provider", "type": "str"},
        "settings": {"key": "settings", "type": "{object}"},
    }

    def __init__(self, **kwargs):
        super(TokenRequest, self).__init__(**kwargs)
        self.provider = kwargs.get("provider", None)
        self.settings = kwargs.get("settings", None)


class TokenResponse(Model):
    """A response that includes a user token.

    :param connection_name: The connection name
    :type connection_name: str
    :param token: The user token
    :type token: str
    :param expiration: Expiration for the token, in ISO 8601 format (e.g.
     "2007-04-05T14:30Z")
    :type expiration: str
    :param channel_id: The channelId of the TokenResponse
    :type channel_id: str
    """

    _attribute_map = {
        "connection_name": {"key": "connectionName", "type": "str"},
        "token": {"key": "token", "type": "str"},
        "expiration": {"key": "expiration", "type": "str"},
        "channel_id": {"key": "channelId", "type": "str"},
    }

    def __init__(self, **kwargs):
        super(TokenResponse, self).__init__(**kwargs)
        self.connection_name = kwargs.get("connection_name", None)
        self.token = kwargs.get("token", None)
        self.expiration = kwargs.get("expiration", None)
        self.channel_id = kwargs.get("channel_id", None)


class Transcript(Model):
    """Transcript.

    :param activities: A collection of Activities that conforms to the
     Transcript schema.
    :type activities: list[~botframework.connector.models.Activity]
    """

    _attribute_map = {"activities": {"key": "activities", "type": "[Activity]"}}

    def __init__(self, **kwargs):
        super(Transcript, self).__init__(**kwargs)
        self.activities = kwargs.get("activities", None)


class VideoCard(Model):
    """Video card.

    :param title: Title of this card
    :type title: str
    :param subtitle: Subtitle of this card
    :type subtitle: str
    :param text: Text of this card
    :type text: str
    :param image: Thumbnail placeholder
    :type image: ~botframework.connector.models.ThumbnailUrl
    :param media: Media URLs for this card. When this field contains more than
     one URL, each URL is an alternative format of the same content.
    :type media: list[~botframework.connector.models.MediaUrl]
    :param buttons: Actions on this card
    :type buttons: list[~botframework.connector.models.CardAction]
    :param shareable: This content may be shared with others (default:true)
    :type shareable: bool
    :param autoloop: Should the client loop playback at end of content
     (default:true)
    :type autoloop: bool
    :param autostart: Should the client automatically start playback of media
     in this card (default:true)
    :type autostart: bool
    :param aspect: Aspect ratio of thumbnail/media placeholder. Allowed values
     are "16:9" and "4:3"
    :type aspect: str
    :param duration: Describes the length of the media content without
     requiring a receiver to open the content. Formatted as an ISO 8601
     Duration field.
    :type duration: str
    :param value: Supplementary parameter for this card
    :type value: object
    """

    _attribute_map = {
        "title": {"key": "title", "type": "str"},
        "subtitle": {"key": "subtitle", "type": "str"},
        "text": {"key": "text", "type": "str"},
        "image": {"key": "image", "type": "ThumbnailUrl"},
        "media": {"key": "media", "type": "[MediaUrl]"},
        "buttons": {"key": "buttons", "type": "[CardAction]"},
        "shareable": {"key": "shareable", "type": "bool"},
        "autoloop": {"key": "autoloop", "type": "bool"},
        "autostart": {"key": "autostart", "type": "bool"},
        "aspect": {"key": "aspect", "type": "str"},
        "duration": {"key": "duration", "type": "str"},
        "value": {"key": "value", "type": "object"},
    }

    def __init__(self, **kwargs):
        super(VideoCard, self).__init__(**kwargs)
        self.title = kwargs.get("title", None)
        self.subtitle = kwargs.get("subtitle", None)
        self.text = kwargs.get("text", None)
        self.image = kwargs.get("image", None)
        self.media = kwargs.get("media", None)
        self.buttons = kwargs.get("buttons", None)
        self.shareable = kwargs.get("shareable", None)
        self.autoloop = kwargs.get("autoloop", None)
        self.autostart = kwargs.get("autostart", None)
        self.aspect = kwargs.get("aspect", None)
        self.duration = kwargs.get("duration", None)
        self.value = kwargs.get("value", None)
