# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
#
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model
from botbuilder.schema import Activity, PagedMembersResult, TeamsChannelAccount


class AppBasedLinkQuery(Model):
    """Invoke request body type for app-based link query.

    :param url: Url queried by user
    :type url: str
    """

    _attribute_map = {
        "url": {"key": "url", "type": "str"},
    }

    def __init__(self, *, url: str = None, **kwargs) -> None:
        super(AppBasedLinkQuery, self).__init__(**kwargs)
        self.url = url


class ChannelInfo(Model):
    """A channel info object which describes the channel.

    :param id: Unique identifier representing a channel
    :type id: str
    :param name: Name of the channel
    :type name: str
    """

    _attribute_map = {
        "id": {"key": "id", "type": "str"},
        "name": {"key": "name", "type": "str"},
    }

    def __init__(self, **kwargs):
        super(ChannelInfo, self).__init__(**kwargs)
        self.id = kwargs.get("id", None)
        self.name = kwargs.get("name", None)


class ConversationList(Model):
    """List of channels under a team.

    :param conversations:
    :type conversations:
     list[~botframework.connector.teams.models.ChannelInfo]
    """

    _attribute_map = {
        "conversations": {"key": "conversations", "type": "[ChannelInfo]"},
    }

    def __init__(self, **kwargs):
        super(ConversationList, self).__init__(**kwargs)
        self.conversations = kwargs.get("conversations", None)


class FileConsentCard(Model):
    """File consent card attachment.

    :param description: File description.
    :type description: str
    :param size_in_bytes: Size of the file to be uploaded in Bytes.
    :type size_in_bytes: long
    :param accept_context: Context sent back to the Bot if user consented to
     upload. This is free flow schema and is sent back in Value field of
     Activity.
    :type accept_context: object
    :param decline_context: Context sent back to the Bot if user declined.
     This is free flow schema and is sent back in Value field of Activity.
    :type decline_context: object
    """

    _attribute_map = {
        "description": {"key": "description", "type": "str"},
        "size_in_bytes": {"key": "sizeInBytes", "type": "long"},
        "accept_context": {"key": "acceptContext", "type": "object"},
        "decline_context": {"key": "declineContext", "type": "object"},
    }

    def __init__(self, **kwargs):
        super(FileConsentCard, self).__init__(**kwargs)
        self.description = kwargs.get("description", None)
        self.size_in_bytes = kwargs.get("size_in_bytes", None)
        self.accept_context = kwargs.get("accept_context", None)
        self.decline_context = kwargs.get("decline_context", None)


class FileConsentCardResponse(Model):
    """Represents the value of the invoke activity sent when the user acts on a
    file consent card.

    :param action: The action the user took. Possible values include:
     'accept', 'decline'
    :type action: str or ~botframework.connector.teams.models.enum
    :param context: The context associated with the action.
    :type context: object
    :param upload_info: If the user accepted the file, contains information
     about the file to be uploaded.
    :type upload_info: ~botframework.connector.teams.models.FileUploadInfo
    """

    _attribute_map = {
        "action": {"key": "action", "type": "str"},
        "context": {"key": "context", "type": "object"},
        "upload_info": {"key": "uploadInfo", "type": "FileUploadInfo"},
    }

    def __init__(self, **kwargs):
        super(FileConsentCardResponse, self).__init__(**kwargs)
        self.action = kwargs.get("action", None)
        self.context = kwargs.get("context", None)
        self.upload_info = kwargs.get("upload_info", None)


class FileDownloadInfo(Model):
    """File download info attachment.

    :param download_url: File download url.
    :type download_url: str
    :param unique_id: Unique Id for the file.
    :type unique_id: str
    :param file_type: Type of file.
    :type file_type: str
    :param etag: ETag for the file.
    :type etag: object
    """

    _attribute_map = {
        "download_url": {"key": "downloadUrl", "type": "str"},
        "unique_id": {"key": "uniqueId", "type": "str"},
        "file_type": {"key": "fileType", "type": "str"},
        "etag": {"key": "etag", "type": "object"},
    }

    def __init__(self, **kwargs):
        super(FileDownloadInfo, self).__init__(**kwargs)
        self.download_url = kwargs.get("download_url", None)
        self.unique_id = kwargs.get("unique_id", None)
        self.file_type = kwargs.get("file_type", None)
        self.etag = kwargs.get("etag", None)


class FileInfoCard(Model):
    """File info card.

    :param unique_id: Unique Id for the file.
    :type unique_id: str
    :param file_type: Type of file.
    :type file_type: str
    :param etag: ETag for the file.
    :type etag: object
    """

    _attribute_map = {
        "unique_id": {"key": "uniqueId", "type": "str"},
        "file_type": {"key": "fileType", "type": "str"},
        "etag": {"key": "etag", "type": "object"},
    }

    def __init__(self, **kwargs):
        super(FileInfoCard, self).__init__(**kwargs)
        self.unique_id = kwargs.get("unique_id", None)
        self.file_type = kwargs.get("file_type", None)
        self.etag = kwargs.get("etag", None)


class FileUploadInfo(Model):
    """Information about the file to be uploaded.

    :param name: Name of the file.
    :type name: str
    :param upload_url: URL to an upload session that the bot can use to set
     the file contents.
    :type upload_url: str
    :param content_url: URL to file.
    :type content_url: str
    :param unique_id: ID that uniquely identifies the file.
    :type unique_id: str
    :param file_type: Type of the file.
    :type file_type: str
    """

    _attribute_map = {
        "name": {"key": "name", "type": "str"},
        "upload_url": {"key": "uploadUrl", "type": "str"},
        "content_url": {"key": "contentUrl", "type": "str"},
        "unique_id": {"key": "uniqueId", "type": "str"},
        "file_type": {"key": "fileType", "type": "str"},
    }

    def __init__(self, **kwargs):
        super(FileUploadInfo, self).__init__(**kwargs)
        self.name = kwargs.get("name", None)
        self.upload_url = kwargs.get("upload_url", None)
        self.content_url = kwargs.get("content_url", None)
        self.unique_id = kwargs.get("unique_id", None)
        self.file_type = kwargs.get("file_type", None)


class MessageActionsPayloadApp(Model):
    """Represents an application entity.

    :param application_identity_type: The type of application. Possible values
     include: 'aadApplication', 'bot', 'tenantBot', 'office365Connector',
     'webhook'
    :type application_identity_type: str or
     ~botframework.connector.teams.models.enum
    :param id: The id of the application.
    :type id: str
    :param display_name: The plaintext display name of the application.
    :type display_name: str
    """

    _attribute_map = {
        "application_identity_type": {"key": "applicationIdentityType", "type": "str"},
        "id": {"key": "id", "type": "str"},
        "display_name": {"key": "displayName", "type": "str"},
    }

    def __init__(self, **kwargs):
        super(MessageActionsPayloadApp, self).__init__(**kwargs)
        self.application_identity_type = kwargs.get("application_identity_type", None)
        self.id = kwargs.get("id", None)
        self.display_name = kwargs.get("display_name", None)


class MessageActionsPayloadAttachment(Model):
    """Represents the attachment in a message.

    :param id: The id of the attachment.
    :type id: str
    :param content_type: The type of the attachment.
    :type content_type: str
    :param content_url: The url of the attachment, in case of a external link.
    :type content_url: str
    :param content: The content of the attachment, in case of a code snippet,
     email, or file.
    :type content: object
    :param name: The plaintext display name of the attachment.
    :type name: str
    :param thumbnail_url: The url of a thumbnail image that might be embedded
     in the attachment, in case of a card.
    :type thumbnail_url: str
    """

    _attribute_map = {
        "id": {"key": "id", "type": "str"},
        "content_type": {"key": "contentType", "type": "str"},
        "content_url": {"key": "contentUrl", "type": "str"},
        "content": {"key": "content", "type": "object"},
        "name": {"key": "name", "type": "str"},
        "thumbnail_url": {"key": "thumbnailUrl", "type": "str"},
    }

    def __init__(self, **kwargs):
        super(MessageActionsPayloadAttachment, self).__init__(**kwargs)
        self.id = kwargs.get("id", None)
        self.content_type = kwargs.get("content_type", None)
        self.content_url = kwargs.get("content_url", None)
        self.content = kwargs.get("content", None)
        self.name = kwargs.get("name", None)
        self.thumbnail_url = kwargs.get("thumbnail_url", None)


class MessageActionsPayloadBody(Model):
    """Plaintext/HTML representation of the content of the message.

    :param content_type: Type of the content. Possible values include: 'html',
     'text'
    :type content_type: str or ~botframework.connector.teams.models.enum
    :param content: The content of the body.
    :type content: str
    """

    _attribute_map = {
        "content_type": {"key": "contentType", "type": "str"},
        "content": {"key": "content", "type": "str"},
    }

    def __init__(self, **kwargs):
        super(MessageActionsPayloadBody, self).__init__(**kwargs)
        self.content_type = kwargs.get("content_type", None)
        self.content = kwargs.get("content", None)


class MessageActionsPayloadConversation(Model):
    """Represents a team or channel entity.

    :param conversation_identity_type: The type of conversation, whether a
     team or channel. Possible values include: 'team', 'channel'
    :type conversation_identity_type: str or
     ~botframework.connector.teams.models.enum
    :param id: The id of the team or channel.
    :type id: str
    :param display_name: The plaintext display name of the team or channel
     entity.
    :type display_name: str
    """

    _attribute_map = {
        "conversation_identity_type": {
            "key": "conversationIdentityType",
            "type": "str",
        },
        "id": {"key": "id", "type": "str"},
        "display_name": {"key": "displayName", "type": "str"},
    }

    def __init__(self, **kwargs):
        super(MessageActionsPayloadConversation, self).__init__(**kwargs)
        self.conversation_identity_type = kwargs.get("conversation_identity_type", None)
        self.id = kwargs.get("id", None)
        self.display_name = kwargs.get("display_name", None)


class MessageActionsPayloadFrom(Model):
    """Represents a user, application, or conversation type that either sent or
    was referenced in a message.

    :param user: Represents details of the user.
    :type user: ~botframework.connector.teams.models.MessageActionsPayloadUser
    :param application: Represents details of the app.
    :type application:
     ~botframework.connector.teams.models.MessageActionsPayloadApp
    :param conversation: Represents details of the converesation.
    :type conversation:
     ~botframework.connector.teams.models.MessageActionsPayloadConversation
    """

    _attribute_map = {
        "user": {"key": "user", "type": "MessageActionsPayloadUser"},
        "application": {"key": "application", "type": "MessageActionsPayloadApp"},
        "conversation": {
            "key": "conversation",
            "type": "MessageActionsPayloadConversation",
        },
    }

    def __init__(self, **kwargs):
        super(MessageActionsPayloadFrom, self).__init__(**kwargs)
        self.user = kwargs.get("user", None)
        self.application = kwargs.get("application", None)
        self.conversation = kwargs.get("conversation", None)


class MessageActionsPayloadMention(Model):
    """Represents the entity that was mentioned in the message.

    :param id: The id of the mentioned entity.
    :type id: int
    :param mention_text: The plaintext display name of the mentioned entity.
    :type mention_text: str
    :param mentioned: Provides more details on the mentioned entity.
    :type mentioned:
     ~botframework.connector.teams.models.MessageActionsPayloadFrom
    """

    _attribute_map = {
        "id": {"key": "id", "type": "int"},
        "mention_text": {"key": "mentionText", "type": "str"},
        "mentioned": {"key": "mentioned", "type": "MessageActionsPayloadFrom"},
    }

    def __init__(self, **kwargs):
        super(MessageActionsPayloadMention, self).__init__(**kwargs)
        self.id = kwargs.get("id", None)
        self.mention_text = kwargs.get("mention_text", None)
        self.mentioned = kwargs.get("mentioned", None)


class MessageActionsPayloadReaction(Model):
    """Represents the reaction of a user to a message.

    :param reaction_type: The type of reaction given to the message. Possible
     values include: 'like', 'heart', 'laugh', 'surprised', 'sad', 'angry'
    :type reaction_type: str or ~botframework.connector.teams.models.enum
    :param created_date_time: Timestamp of when the user reacted to the
     message.
    :type created_date_time: str
    :param user: The user with which the reaction is associated.
    :type user: ~botframework.connector.teams.models.MessageActionsPayloadFrom
    """

    _attribute_map = {
        "reaction_type": {"key": "reactionType", "type": "str"},
        "created_date_time": {"key": "createdDateTime", "type": "str"},
        "user": {"key": "user", "type": "MessageActionsPayloadFrom"},
    }

    def __init__(self, **kwargs):
        super(MessageActionsPayloadReaction, self).__init__(**kwargs)
        self.reaction_type = kwargs.get("reaction_type", None)
        self.created_date_time = kwargs.get("created_date_time", None)
        self.user = kwargs.get("user", None)


class MessageActionsPayloadUser(Model):
    """Represents a user entity.

    :param user_identity_type: The identity type of the user. Possible values
     include: 'aadUser', 'onPremiseAadUser', 'anonymousGuest', 'federatedUser'
    :type user_identity_type: str or ~botframework.connector.teams.models.enum
    :param id: The id of the user.
    :type id: str
    :param display_name: The plaintext display name of the user.
    :type display_name: str
    """

    _attribute_map = {
        "user_identity_type": {"key": "userIdentityType", "type": "str"},
        "id": {"key": "id", "type": "str"},
        "display_name": {"key": "displayName", "type": "str"},
    }

    def __init__(self, **kwargs):
        super(MessageActionsPayloadUser, self).__init__(**kwargs)
        self.user_identity_type = kwargs.get("user_identity_type", None)
        self.id = kwargs.get("id", None)
        self.display_name = kwargs.get("display_name", None)


class MessageActionsPayload(Model):
    """Represents the individual message within a chat or channel where a message
    actions is taken.

    :param id: Unique id of the message.
    :type id: str
    :param reply_to_id: Id of the parent/root message of the thread.
    :type reply_to_id: str
    :param message_type: Type of message - automatically set to message.
     Possible values include: 'message'
    :type message_type: str or ~botframework.connector.teams.models.enum
    :param created_date_time: Timestamp of when the message was created.
    :type created_date_time: str
    :param last_modified_date_time: Timestamp of when the message was edited
     or updated.
    :type last_modified_date_time: str
    :param deleted: Indicates whether a message has been soft deleted.
    :type deleted: bool
    :param subject: Subject line of the message.
    :type subject: str
    :param summary: Summary text of the message that could be used for
     notifications.
    :type summary: str
    :param importance: The importance of the message. Possible values include:
     'normal', 'high', 'urgent'
    :type importance: str or ~botframework.connector.teams.models.enum
    :param locale: Locale of the message set by the client.
    :type locale: str
    :param from_property: Sender of the message.
    :type from_property:
     ~botframework.connector.teams.models.MessageActionsPayloadFrom
    :param body: Plaintext/HTML representation of the content of the message.
    :type body: ~botframework.connector.teams.models.MessageActionsPayloadBody
    :param attachment_layout: How the attachment(s) are displayed in the
     message.
    :type attachment_layout: str
    :param attachments: Attachments in the message - card, image, file, etc.
    :type attachments:
     list[~botframework.connector.teams.models.MessageActionsPayloadAttachment]
    :param mentions: List of entities mentioned in the message.
    :type mentions:
     list[~botframework.connector.teams.models.MessageActionsPayloadMention]
    :param reactions: Reactions for the message.
    :type reactions:
     list[~botframework.connector.teams.models.MessageActionsPayloadReaction]
    """

    _attribute_map = {
        "id": {"key": "id", "type": "str"},
        "reply_to_id": {"key": "replyToId", "type": "str"},
        "message_type": {"key": "messageType", "type": "str"},
        "created_date_time": {"key": "createdDateTime", "type": "str"},
        "last_modified_date_time": {"key": "lastModifiedDateTime", "type": "str"},
        "deleted": {"key": "deleted", "type": "bool"},
        "subject": {"key": "subject", "type": "str"},
        "summary": {"key": "summary", "type": "str"},
        "importance": {"key": "importance", "type": "str"},
        "locale": {"key": "locale", "type": "str"},
        "from_property": {"key": "from", "type": "MessageActionsPayloadFrom"},
        "body": {"key": "body", "type": "MessageActionsPayloadBody"},
        "attachment_layout": {"key": "attachmentLayout", "type": "str"},
        "attachments": {
            "key": "attachments",
            "type": "[MessageActionsPayloadAttachment]",
        },
        "mentions": {"key": "mentions", "type": "[MessageActionsPayloadMention]"},
        "reactions": {"key": "reactions", "type": "[MessageActionsPayloadReaction]"},
    }

    def __init__(self, **kwargs):
        super(MessageActionsPayload, self).__init__(**kwargs)
        self.id = kwargs.get("id", None)
        self.reply_to_id = kwargs.get("reply_to_id", None)
        self.message_type = kwargs.get("message_type", None)
        self.created_date_time = kwargs.get("created_date_time", None)
        self.last_modified_date_time = kwargs.get("last_modified_date_time", None)
        self.deleted = kwargs.get("deleted", None)
        self.subject = kwargs.get("subject", None)
        self.summary = kwargs.get("summary", None)
        self.importance = kwargs.get("importance", None)
        self.locale = kwargs.get("locale", None)
        self.from_property = kwargs.get("from_property", None)
        self.body = kwargs.get("body", None)
        self.attachment_layout = kwargs.get("attachment_layout", None)
        self.attachments = kwargs.get("attachments", None)
        self.mentions = kwargs.get("mentions", None)
        self.reactions = kwargs.get("reactions", None)


class MessagingExtensionAction(TaskModuleRequest):
    """Messaging extension action.

    :param data: User input data. Free payload with key-value pairs.
    :type data: object
    :param context: Current user context, i.e., the current theme
    :type context:
     ~botframework.connector.teams.models.TaskModuleRequestContext
    :param command_id: Id of the command assigned by Bot
    :type command_id: str
    :param command_context: The context from which the command originates.
     Possible values include: 'message', 'compose', 'commandbox'
    :type command_context: str or ~botframework.connector.teams.models.enum
    :param bot_message_preview_action: Bot message preview action taken by
     user. Possible values include: 'edit', 'send'
    :type bot_message_preview_action: str or
     ~botframework.connector.teams.models.enum
    :param bot_activity_preview:
    :type bot_activity_preview:
     list[~botframework.connector.teams.models.Activity]
    :param message_payload: Message content sent as part of the command
     request.
    :type message_payload:
     ~botframework.connector.teams.models.MessageActionsPayload
    """

    _attribute_map = {
        "data": {"key": "data", "type": "object"},
        "context": {"key": "context", "type": "TaskModuleRequestContext"},
        "command_id": {"key": "commandId", "type": "str"},
        "command_context": {"key": "commandContext", "type": "str"},
        "bot_message_preview_action": {"key": "botMessagePreviewAction", "type": "str"},
        "bot_activity_preview": {"key": "botActivityPreview", "type": "[Activity]"},
        "message_payload": {"key": "messagePayload", "type": "MessageActionsPayload"},
    }

    def __init__(self, **kwargs):
        super(MessagingExtensionAction, self).__init__(**kwargs)
        self.command_id = kwargs.get("command_id", None)
        self.command_context = kwargs.get("command_context", None)
        self.bot_message_preview_action = kwargs.get("bot_message_preview_action", None)
        self.bot_activity_preview = kwargs.get("bot_activity_preview", None)
        self.message_payload = kwargs.get("message_payload", None)


class MessagingExtensionActionResponse(Model):
    """Response of messaging extension action.

    :param task: The JSON for the Adaptive card to appear in the task module.
    :type task: ~botframework.connector.teams.models.TaskModuleResponseBase
    :param compose_extension:
    :type compose_extension:
     ~botframework.connector.teams.models.MessagingExtensionResult
    """

    _attribute_map = {
        "task": {"key": "task", "type": "TaskModuleResponseBase"},
        "compose_extension": {
            "key": "composeExtension",
            "type": "MessagingExtensionResult",
        },
    }

    def __init__(self, **kwargs):
        super(MessagingExtensionActionResponse, self).__init__(**kwargs)
        self.task = kwargs.get("task", None)
        self.compose_extension = kwargs.get("compose_extension", None)


class MessagingExtensionAttachment(Attachment):
    """Messaging extension attachment.

    :param content_type: mimetype/Contenttype for the file
    :type content_type: str
    :param content_url: Content Url
    :type content_url: str
    :param content: Embedded content
    :type content: object
    :param name: (OPTIONAL) The name of the attachment
    :type name: str
    :param thumbnail_url: (OPTIONAL) Thumbnail associated with attachment
    :type thumbnail_url: str
    :param preview:
    :type preview: ~botframework.connector.teams.models.Attachment
    """

    _attribute_map = {
        "content_type": {"key": "contentType", "type": "str"},
        "content_url": {"key": "contentUrl", "type": "str"},
        "content": {"key": "content", "type": "object"},
        "name": {"key": "name", "type": "str"},
        "thumbnail_url": {"key": "thumbnailUrl", "type": "str"},
        "preview": {"key": "preview", "type": "Attachment"},
    }

    def __init__(self, **kwargs):
        super(MessagingExtensionAttachment, self).__init__(**kwargs)
        self.preview = kwargs.get("preview", None)


class MessagingExtensionParameter(Model):
    """Messaging extension query parameters.

    :param name: Name of the parameter
    :type name: str
    :param value: Value of the parameter
    :type value: object
    """

    _attribute_map = {
        "name": {"key": "name", "type": "str"},
        "value": {"key": "value", "type": "object"},
    }

    def __init__(self, **kwargs):
        super(MessagingExtensionParameter, self).__init__(**kwargs)
        self.name = kwargs.get("name", None)
        self.value = kwargs.get("value", None)


class MessagingExtensionQuery(Model):
    """Messaging extension query.

    :param command_id: Id of the command assigned by Bot
    :type command_id: str
    :param parameters: Parameters for the query
    :type parameters:
     list[~botframework.connector.teams.models.MessagingExtensionParameter]
    :param query_options:
    :type query_options:
     ~botframework.connector.teams.models.MessagingExtensionQueryOptions
    :param state: State parameter passed back to the bot after
     authentication/configuration flow
    :type state: str
    """

    _attribute_map = {
        "command_id": {"key": "commandId", "type": "str"},
        "parameters": {"key": "parameters", "type": "[MessagingExtensionParameter]"},
        "query_options": {
            "key": "queryOptions",
            "type": "MessagingExtensionQueryOptions",
        },
        "state": {"key": "state", "type": "str"},
    }

    def __init__(self, **kwargs):
        super(MessagingExtensionQuery, self).__init__(**kwargs)
        self.command_id = kwargs.get("command_id", None)
        self.parameters = kwargs.get("parameters", None)
        self.query_options = kwargs.get("query_options", None)
        self.state = kwargs.get("state", None)


class MessagingExtensionQueryOptions(Model):
    """Messaging extension query options.

    :param skip: Number of entities to skip
    :type skip: int
    :param count: Number of entities to fetch
    :type count: int
    """

    _attribute_map = {
        "skip": {"key": "skip", "type": "int"},
        "count": {"key": "count", "type": "int"},
    }

    def __init__(self, **kwargs):
        super(MessagingExtensionQueryOptions, self).__init__(**kwargs)
        self.skip = kwargs.get("skip", None)
        self.count = kwargs.get("count", None)


class MessagingExtensionResponse(Model):
    """Messaging extension response.

    :param compose_extension:
    :type compose_extension:
     ~botframework.connector.teams.models.MessagingExtensionResult
    """

    _attribute_map = {
        "compose_extension": {
            "key": "composeExtension",
            "type": "MessagingExtensionResult",
        },
    }

    def __init__(self, **kwargs):
        super(MessagingExtensionResponse, self).__init__(**kwargs)
        self.compose_extension = kwargs.get("compose_extension", None)


class MessagingExtensionResult(Model):
    """Messaging extension result.

    :param attachment_layout: Hint for how to deal with multiple attachments.
     Possible values include: 'list', 'grid'
    :type attachment_layout: str or ~botframework.connector.teams.models.enum
    :param type: The type of the result. Possible values include: 'result',
     'auth', 'config', 'message', 'botMessagePreview'
    :type type: str or ~botframework.connector.teams.models.enum
    :param attachments: (Only when type is result) Attachments
    :type attachments:
     list[~botframework.connector.teams.models.MessagingExtensionAttachment]
    :param suggested_actions:
    :type suggested_actions:
     ~botframework.connector.teams.models.MessagingExtensionSuggestedAction
    :param text: (Only when type is message) Text
    :type text: str
    :param activity_preview: (Only when type is botMessagePreview) Message
     activity to preview
    :type activity_preview: ~botframework.connector.teams.models.Activity
    """

    _attribute_map = {
        "attachment_layout": {"key": "attachmentLayout", "type": "str"},
        "type": {"key": "type", "type": "str"},
        "attachments": {"key": "attachments", "type": "[MessagingExtensionAttachment]"},
        "suggested_actions": {
            "key": "suggestedActions",
            "type": "MessagingExtensionSuggestedAction",
        },
        "text": {"key": "text", "type": "str"},
        "activity_preview": {"key": "activityPreview", "type": "Activity"},
    }

    def __init__(self, **kwargs):
        super(MessagingExtensionResult, self).__init__(**kwargs)
        self.attachment_layout = kwargs.get("attachment_layout", None)
        self.type = kwargs.get("type", None)
        self.attachments = kwargs.get("attachments", None)
        self.suggested_actions = kwargs.get("suggested_actions", None)
        self.text = kwargs.get("text", None)
        self.activity_preview = kwargs.get("activity_preview", None)


class MessagingExtensionSuggestedAction(Model):
    """Messaging extension Actions (Only when type is auth or config).

    :param actions: Actions
    :type actions: list[~botframework.connector.teams.models.CardAction]
    """

    _attribute_map = {
        "actions": {"key": "actions", "type": "[CardAction]"},
    }

    def __init__(self, **kwargs):
        super(MessagingExtensionSuggestedAction, self).__init__(**kwargs)
        self.actions = kwargs.get("actions", None)


class NotificationInfo(Model):
    """Specifies if a notification is to be sent for the mentions.

    :param alert: true if notification is to be sent to the user, false
     otherwise.
    :type alert: bool
    """

    _attribute_map = {
        "alert": {"key": "alert", "type": "bool"},
    }

    def __init__(self, **kwargs):
        super(NotificationInfo, self).__init__(**kwargs)
        self.alert = kwargs.get("alert", None)


class O365ConnectorCard(Model):
    """O365 connector card.

    :param title: Title of the item
    :type title: str
    :param text: Text for the card
    :type text: str
    :param summary: Summary for the card
    :type summary: str
    :param theme_color: Theme color for the card
    :type theme_color: str
    :param sections: Set of sections for the current card
    :type sections:
     list[~botframework.connector.teams.models.O365ConnectorCardSection]
    :param potential_action: Set of actions for the current card
    :type potential_action:
     list[~botframework.connector.teams.models.O365ConnectorCardActionBase]
    """

    _attribute_map = {
        "title": {"key": "title", "type": "str"},
        "text": {"key": "text", "type": "str"},
        "summary": {"key": "summary", "type": "str"},
        "theme_color": {"key": "themeColor", "type": "str"},
        "sections": {"key": "sections", "type": "[O365ConnectorCardSection]"},
        "potential_action": {
            "key": "potentialAction",
            "type": "[O365ConnectorCardActionBase]",
        },
    }

    def __init__(self, **kwargs):
        super(O365ConnectorCard, self).__init__(**kwargs)
        self.title = kwargs.get("title", None)
        self.text = kwargs.get("text", None)
        self.summary = kwargs.get("summary", None)
        self.theme_color = kwargs.get("theme_color", None)
        self.sections = kwargs.get("sections", None)
        self.potential_action = kwargs.get("potential_action", None)


class O365ConnectorCardActionBase(Model):
    """O365 connector card action base.

    :param type: Type of the action. Possible values include: 'ViewAction',
     'OpenUri', 'HttpPOST', 'ActionCard'
    :type type: str or ~botframework.connector.teams.models.enum
    :param name: Name of the action that will be used as button title
    :type name: str
    :param id: Action Id
    :type id: str
    """

    _attribute_map = {
        "type": {"key": "@type", "type": "str"},
        "name": {"key": "name", "type": "str"},
        "id": {"key": "@id", "type": "str"},
    }

    def __init__(self, **kwargs):
        super(O365ConnectorCardActionBase, self).__init__(**kwargs)
        self.type = kwargs.get("type", None)
        self.name = kwargs.get("name", None)
        self.id = kwargs.get("id", None)


class O365ConnectorCardActionCard(O365ConnectorCardActionBase):
    """O365 connector card ActionCard action.

    :param type: Type of the action. Possible values include: 'ViewAction',
     'OpenUri', 'HttpPOST', 'ActionCard'
    :type type: str or ~botframework.connector.teams.models.enum
    :param name: Name of the action that will be used as button title
    :type name: str
    :param id: Action Id
    :type id: str
    :param inputs: Set of inputs contained in this ActionCard whose each item
     can be in any subtype of O365ConnectorCardInputBase
    :type inputs:
     list[~botframework.connector.teams.models.O365ConnectorCardInputBase]
    :param actions: Set of actions contained in this ActionCard whose each
     item can be in any subtype of O365ConnectorCardActionBase except
     O365ConnectorCardActionCard, as nested ActionCard is forbidden.
    :type actions:
     list[~botframework.connector.teams.models.O365ConnectorCardActionBase]
    """

    _attribute_map = {
        "type": {"key": "@type", "type": "str"},
        "name": {"key": "name", "type": "str"},
        "id": {"key": "@id", "type": "str"},
        "inputs": {"key": "inputs", "type": "[O365ConnectorCardInputBase]"},
        "actions": {"key": "actions", "type": "[O365ConnectorCardActionBase]"},
    }

    def __init__(self, **kwargs):
        super(O365ConnectorCardActionCard, self).__init__(**kwargs)
        self.inputs = kwargs.get("inputs", None)
        self.actions = kwargs.get("actions", None)


class O365ConnectorCardActionQuery(Model):
    """O365 connector card HttpPOST invoke query.

    :param body: The results of body string defined in
     IO365ConnectorCardHttpPOST with substituted input values
    :type body: str
    :param action_id: Action Id associated with the HttpPOST action button
     triggered, defined in O365ConnectorCardActionBase.
    :type action_id: str
    """

    _attribute_map = {
        "body": {"key": "body", "type": "str"},
        "action_id": {"key": "actionId", "type": "str"},
    }

    def __init__(self, **kwargs):
        super(O365ConnectorCardActionQuery, self).__init__(**kwargs)
        self.body = kwargs.get("body", None)
        # This is how it comes in from Teams
        self.action_id = kwargs.get("actionId", None)


class O365ConnectorCardDateInput(O365ConnectorCardInputBase):
    """O365 connector card date input.

    :param type: Input type name. Possible values include: 'textInput',
     'dateInput', 'multichoiceInput'
    :type type: str or ~botframework.connector.teams.models.enum
    :param id: Input Id. It must be unique per entire O365 connector card.
    :type id: str
    :param is_required: Define if this input is a required field. Default
     value is false.
    :type is_required: bool
    :param title: Input title that will be shown as the placeholder
    :type title: str
    :param value: Default value for this input field
    :type value: str
    :param include_time: Include time input field. Default value  is false
     (date only).
    :type include_time: bool
    """

    _attribute_map = {
        "type": {"key": "@type", "type": "str"},
        "id": {"key": "id", "type": "str"},
        "is_required": {"key": "isRequired", "type": "bool"},
        "title": {"key": "title", "type": "str"},
        "value": {"key": "value", "type": "str"},
        "include_time": {"key": "includeTime", "type": "bool"},
    }

    def __init__(self, **kwargs):
        super(O365ConnectorCardDateInput, self).__init__(**kwargs)
        self.include_time = kwargs.get("include_time", None)


class O365ConnectorCardFact(Model):
    """O365 connector card fact.

    :param name: Display name of the fact
    :type name: str
    :param value: Display value for the fact
    :type value: str
    """

    _attribute_map = {
        "name": {"key": "name", "type": "str"},
        "value": {"key": "value", "type": "str"},
    }

    def __init__(self, **kwargs):
        super(O365ConnectorCardFact, self).__init__(**kwargs)
        self.name = kwargs.get("name", None)
        self.value = kwargs.get("value", None)


class O365ConnectorCardHttpPOST(O365ConnectorCardActionBase):
    """O365 connector card HttpPOST action.

    :param type: Type of the action. Possible values include: 'ViewAction',
     'OpenUri', 'HttpPOST', 'ActionCard'
    :type type: str or ~botframework.connector.teams.models.enum
    :param name: Name of the action that will be used as button title
    :type name: str
    :param id: Action Id
    :type id: str
    :param body: Content to be posted back to bots via invoke
    :type body: str
    """

    _attribute_map = {
        "type": {"key": "@type", "type": "str"},
        "name": {"key": "name", "type": "str"},
        "id": {"key": "@id", "type": "str"},
        "body": {"key": "body", "type": "str"},
    }

    def __init__(self, **kwargs):
        super(O365ConnectorCardHttpPOST, self).__init__(**kwargs)
        self.body = kwargs.get("body", None)


class O365ConnectorCardImage(Model):
    """O365 connector card image.

    :param image: URL for the image
    :type image: str
    :param title: Alternative text for the image
    :type title: str
    """

    _attribute_map = {
        "image": {"key": "image", "type": "str"},
        "title": {"key": "title", "type": "str"},
    }

    def __init__(self, **kwargs):
        super(O365ConnectorCardImage, self).__init__(**kwargs)
        self.image = kwargs.get("image", None)
        self.title = kwargs.get("title", None)


class O365ConnectorCardInputBase(Model):
    """O365 connector card input for ActionCard action.

    :param type: Input type name. Possible values include: 'textInput',
     'dateInput', 'multichoiceInput'
    :type type: str or ~botframework.connector.teams.models.enum
    :param id: Input Id. It must be unique per entire O365 connector card.
    :type id: str
    :param is_required: Define if this input is a required field. Default
     value is false.
    :type is_required: bool
    :param title: Input title that will be shown as the placeholder
    :type title: str
    :param value: Default value for this input field
    :type value: str
    """

    _attribute_map = {
        "type": {"key": "@type", "type": "str"},
        "id": {"key": "id", "type": "str"},
        "is_required": {"key": "isRequired", "type": "bool"},
        "title": {"key": "title", "type": "str"},
        "value": {"key": "value", "type": "str"},
    }

    def __init__(self, **kwargs):
        super(O365ConnectorCardInputBase, self).__init__(**kwargs)
        self.type = kwargs.get("type", None)
        self.id = kwargs.get("id", None)
        self.is_required = kwargs.get("is_required", None)
        self.title = kwargs.get("title", None)
        self.value = kwargs.get("value", None)


class O365ConnectorCardMultichoiceInput(O365ConnectorCardInputBase):
    """O365 connector card multiple choice input.

    :param type: Input type name. Possible values include: 'textInput',
     'dateInput', 'multichoiceInput'
    :type type: str or ~botframework.connector.teams.models.enum
    :param id: Input Id. It must be unique per entire O365 connector card.
    :type id: str
    :param is_required: Define if this input is a required field. Default
     value is false.
    :type is_required: bool
    :param title: Input title that will be shown as the placeholder
    :type title: str
    :param value: Default value for this input field
    :type value: str
    :param choices: Set of choices whose each item can be in any subtype of
     O365ConnectorCardMultichoiceInputChoice.
    :type choices:
     list[~botframework.connector.teams.models.O365ConnectorCardMultichoiceInputChoice]
    :param style: Choice item rendering style. Default value is 'compact'.
     Possible values include: 'compact', 'expanded'
    :type style: str or ~botframework.connector.teams.models.enum
    :param is_multi_select: Define if this input field allows multiple
     selections. Default value is false.
    :type is_multi_select: bool
    """

    _attribute_map = {
        "type": {"key": "@type", "type": "str"},
        "id": {"key": "id", "type": "str"},
        "is_required": {"key": "isRequired", "type": "bool"},
        "title": {"key": "title", "type": "str"},
        "value": {"key": "value", "type": "str"},
        "choices": {
            "key": "choices",
            "type": "[O365ConnectorCardMultichoiceInputChoice]",
        },
        "style": {"key": "style", "type": "str"},
        "is_multi_select": {"key": "isMultiSelect", "type": "bool"},
    }

    def __init__(self, **kwargs):
        super(O365ConnectorCardMultichoiceInput, self).__init__(**kwargs)
        self.choices = kwargs.get("choices", None)
        self.style = kwargs.get("style", None)
        self.is_multi_select = kwargs.get("is_multi_select", None)


class O365ConnectorCardMultichoiceInputChoice(Model):
    """O365O365 connector card multiple choice input item.

    :param display: The text rendered on ActionCard.
    :type display: str
    :param value: The value received as results.
    :type value: str
    """

    _attribute_map = {
        "display": {"key": "display", "type": "str"},
        "value": {"key": "value", "type": "str"},
    }

    def __init__(self, **kwargs):
        super(O365ConnectorCardMultichoiceInputChoice, self).__init__(**kwargs)
        self.display = kwargs.get("display", None)
        self.value = kwargs.get("value", None)


class O365ConnectorCardOpenUriTarget(Model):
    """O365 connector card OpenUri target.

    :param os: Target operating system. Possible values include: 'default',
     'iOS', 'android', 'windows'
    :type os: str or ~botframework.connector.teams.models.enum
    :param uri: Target url
    :type uri: str
    """

    _attribute_map = {
        "os": {"key": "os", "type": "str"},
        "uri": {"key": "uri", "type": "str"},
    }

    def __init__(self, **kwargs):
        super(O365ConnectorCardOpenUriTarget, self).__init__(**kwargs)
        self.os = kwargs.get("os", None)
        self.uri = kwargs.get("uri", None)


class O365ConnectorCardOpenUri(O365ConnectorCardActionBase):
    """O365 connector card OpenUri action.

    :param type: Type of the action. Possible values include: 'ViewAction',
     'OpenUri', 'HttpPOST', 'ActionCard'
    :type type: str or ~botframework.connector.teams.models.enum
    :param name: Name of the action that will be used as button title
    :type name: str
    :param id: Action Id
    :type id: str
    :param targets: Target os / urls
    :type targets:
     list[~botframework.connector.teams.models.O365ConnectorCardOpenUriTarget]
    """

    _attribute_map = {
        "type": {"key": "@type", "type": "str"},
        "name": {"key": "name", "type": "str"},
        "id": {"key": "@id", "type": "str"},
        "targets": {"key": "targets", "type": "[O365ConnectorCardOpenUriTarget]"},
    }

    def __init__(self, **kwargs):
        super(O365ConnectorCardOpenUri, self).__init__(**kwargs)
        self.targets = kwargs.get("targets", None)


class O365ConnectorCardSection(Model):
    """O365 connector card section.

    :param title: Title of the section
    :type title: str
    :param text: Text for the section
    :type text: str
    :param activity_title: Activity title
    :type activity_title: str
    :param activity_subtitle: Activity subtitle
    :type activity_subtitle: str
    :param activity_text: Activity text
    :type activity_text: str
    :param activity_image: Activity image
    :type activity_image: str
    :param activity_image_type: Describes how Activity image is rendered.
     Possible values include: 'avatar', 'article'
    :type activity_image_type: str or
     ~botframework.connector.teams.models.enum
    :param markdown: Use markdown for all text contents. Default value is
     true.
    :type markdown: bool
    :param facts: Set of facts for the current section
    :type facts:
     list[~botframework.connector.teams.models.O365ConnectorCardFact]
    :param images: Set of images for the current section
    :type images:
     list[~botframework.connector.teams.models.O365ConnectorCardImage]
    :param potential_action: Set of actions for the current section
    :type potential_action:
     list[~botframework.connector.teams.models.O365ConnectorCardActionBase]
    """

    _attribute_map = {
        "title": {"key": "title", "type": "str"},
        "text": {"key": "text", "type": "str"},
        "activity_title": {"key": "activityTitle", "type": "str"},
        "activity_subtitle": {"key": "activitySubtitle", "type": "str"},
        "activity_text": {"key": "activityText", "type": "str"},
        "activity_image": {"key": "activityImage", "type": "str"},
        "activity_image_type": {"key": "activityImageType", "type": "str"},
        "markdown": {"key": "markdown", "type": "bool"},
        "facts": {"key": "facts", "type": "[O365ConnectorCardFact]"},
        "images": {"key": "images", "type": "[O365ConnectorCardImage]"},
        "potential_action": {
            "key": "potentialAction",
            "type": "[O365ConnectorCardActionBase]",
        },
    }

    def __init__(self, **kwargs):
        super(O365ConnectorCardSection, self).__init__(**kwargs)
        self.title = kwargs.get("title", None)
        self.text = kwargs.get("text", None)
        self.activity_title = kwargs.get("activity_title", None)
        self.activity_subtitle = kwargs.get("activity_subtitle", None)
        self.activity_text = kwargs.get("activity_text", None)
        self.activity_image = kwargs.get("activity_image", None)
        self.activity_image_type = kwargs.get("activity_image_type", None)
        self.markdown = kwargs.get("markdown", None)
        self.facts = kwargs.get("facts", None)
        self.images = kwargs.get("images", None)
        self.potential_action = kwargs.get("potential_action", None)


class O365ConnectorCardTextInput(O365ConnectorCardInputBase):
    """O365 connector card text input.

    :param type: Input type name. Possible values include: 'textInput',
     'dateInput', 'multichoiceInput'
    :type type: str or ~botframework.connector.teams.models.enum
    :param id: Input Id. It must be unique per entire O365 connector card.
    :type id: str
    :param is_required: Define if this input is a required field. Default
     value is false.
    :type is_required: bool
    :param title: Input title that will be shown as the placeholder
    :type title: str
    :param value: Default value for this input field
    :type value: str
    :param is_multiline: Define if text input is allowed for multiple lines.
     Default value is false.
    :type is_multiline: bool
    :param max_length: Maximum length of text input. Default value is
     unlimited.
    :type max_length: float
    """

    _attribute_map = {
        "type": {"key": "@type", "type": "str"},
        "id": {"key": "id", "type": "str"},
        "is_required": {"key": "isRequired", "type": "bool"},
        "title": {"key": "title", "type": "str"},
        "value": {"key": "value", "type": "str"},
        "is_multiline": {"key": "isMultiline", "type": "bool"},
        "max_length": {"key": "maxLength", "type": "float"},
    }

    def __init__(self, **kwargs):
        super(O365ConnectorCardTextInput, self).__init__(**kwargs)
        self.is_multiline = kwargs.get("is_multiline", None)
        self.max_length = kwargs.get("max_length", None)


class O365ConnectorCardViewAction(O365ConnectorCardActionBase):
    """O365 connector card ViewAction action.

    :param type: Type of the action. Possible values include: 'ViewAction',
     'OpenUri', 'HttpPOST', 'ActionCard'
    :type type: str or ~botframework.connector.teams.models.enum
    :param name: Name of the action that will be used as button title
    :type name: str
    :param id: Action Id
    :type id: str
    :param target: Target urls, only the first url effective for card button
    :type target: list[str]
    """

    _attribute_map = {
        "type": {"key": "@type", "type": "str"},
        "name": {"key": "name", "type": "str"},
        "id": {"key": "@id", "type": "str"},
        "target": {"key": "target", "type": "[str]"},
    }

    def __init__(self, **kwargs):
        super(O365ConnectorCardViewAction, self).__init__(**kwargs)
        self.target = kwargs.get("target", None)


class SigninStateVerificationQuery(Model):
    """Signin state (part of signin action auth flow) verification invoke query.

    :param state:  The state string originally received when the signin web
     flow is finished with a state posted back to client via tab SDK
     microsoftTeams.authentication.notifySuccess(state)
    :type state: str
    """

    _attribute_map = {
        "state": {"key": "state", "type": "str"},
    }

    def __init__(self, **kwargs):
        super(SigninStateVerificationQuery, self).__init__(**kwargs)
        self.state = kwargs.get("state", None)


class TaskModuleContinueResponse(TaskModuleResponseBase):
    """Task Module Response with continue action.

    :param type: Choice of action options when responding to the task/submit
     message. Possible values include: 'message', 'continue'
    :type type: str or ~botframework.connector.teams.models.enum
    :param value: The JSON for the Adaptive card to appear in the task module.
    :type value: ~botframework.connector.teams.models.TaskModuleTaskInfo
    """

    _attribute_map = {
        "type": {"key": "type", "type": "str"},
        "value": {"key": "value", "type": "TaskModuleTaskInfo"},
    }

    def __init__(self, **kwargs):
        super(TaskModuleContinueResponse, self).__init__(**kwargs)
        self.value = kwargs.get("value", None)


class TaskModuleMessageResponse(TaskModuleResponseBase):
    """Task Module response with message action.

    :param type: Choice of action options when responding to the task/submit
     message. Possible values include: 'message', 'continue'
    :type type: str or ~botframework.connector.teams.models.enum
    :param value: Teams will display the value of value in a popup message
     box.
    :type value: str
    """

    _attribute_map = {
        "type": {"key": "type", "type": "str"},
        "value": {"key": "value", "type": "str"},
    }

    def __init__(self, **kwargs):
        super(TaskModuleMessageResponse, self).__init__(**kwargs)
        self.value = kwargs.get("value", None)


class TaskModuleRequest(Model):
    """Task module invoke request value payload.

    :param data: User input data. Free payload with key-value pairs.
    :type data: object
    :param context: Current user context, i.e., the current theme
    :type context:
     ~botframework.connector.teams.models.TaskModuleRequestContext
    """

    _attribute_map = {
        "data": {"key": "data", "type": "object"},
        "context": {"key": "context", "type": "TaskModuleRequestContext"},
    }

    def __init__(self, **kwargs):
        super(TaskModuleRequest, self).__init__(**kwargs)
        self.data = kwargs.get("data", None)
        self.context = kwargs.get("context", None)


class TaskModuleRequestContext(Model):
    """Current user context, i.e., the current theme.

    :param theme:
    :type theme: str
    """

    _attribute_map = {
        "theme": {"key": "theme", "type": "str"},
    }

    def __init__(self, **kwargs):
        super(TaskModuleRequestContext, self).__init__(**kwargs)
        self.theme = kwargs.get("theme", None)


class TaskModuleResponse(Model):
    """Envelope for Task Module Response.

    :param task: The JSON for the Adaptive card to appear in the task module.
    :type task: ~botframework.connector.teams.models.TaskModuleResponseBase
    """

    _attribute_map = {
        "task": {"key": "task", "type": "TaskModuleResponseBase"},
    }

    def __init__(self, **kwargs):
        super(TaskModuleResponse, self).__init__(**kwargs)
        self.task = kwargs.get("task", None)


class TaskModuleResponseBase(Model):
    """Base class for Task Module responses.

    :param type: Choice of action options when responding to the task/submit
     message. Possible values include: 'message', 'continue'
    :type type: str or ~botframework.connector.teams.models.enum
    """

    _attribute_map = {
        "type": {"key": "type", "type": "str"},
    }

    def __init__(self, **kwargs):
        super(TaskModuleResponseBase, self).__init__(**kwargs)
        self.type = kwargs.get("type", None)


class TaskModuleTaskInfo(Model):
    """Metadata for a Task Module.

    :param title: Appears below the app name and to the right of the app icon.
    :type title: str
    :param height: This can be a number, representing the task module's height
     in pixels, or a string, one of: small, medium, large.
    :type height: object
    :param width: This can be a number, representing the task module's width
     in pixels, or a string, one of: small, medium, large.
    :type width: object
    :param url: The URL of what is loaded as an iframe inside the task module.
     One of url or card is required.
    :type url: str
    :param card: The JSON for the Adaptive card to appear in the task module.
    :type card: ~botframework.connector.teams.models.Attachment
    :param fallback_url: If a client does not support the task module feature,
     this URL is opened in a browser tab.
    :type fallback_url: str
    :param completion_bot_id: If a client does not support the task module
     feature, this URL is opened in a browser tab.
    :type completion_bot_id: str
    """

    _attribute_map = {
        "title": {"key": "title", "type": "str"},
        "height": {"key": "height", "type": "object"},
        "width": {"key": "width", "type": "object"},
        "url": {"key": "url", "type": "str"},
        "card": {"key": "card", "type": "Attachment"},
        "fallback_url": {"key": "fallbackUrl", "type": "str"},
        "completion_bot_id": {"key": "completionBotId", "type": "str"},
    }

    def __init__(self, **kwargs):
        super(TaskModuleTaskInfo, self).__init__(**kwargs)
        self.title = kwargs.get("title", None)
        self.height = kwargs.get("height", None)
        self.width = kwargs.get("width", None)
        self.url = kwargs.get("url", None)
        self.card = kwargs.get("card", None)
        self.fallback_url = kwargs.get("fallback_url", None)
        self.completion_bot_id = kwargs.get("completion_bot_id", None)


class TeamDetails(Model):
    """Details related to a team.

    :param id: Unique identifier representing a team
    :type id: str
    :param name: Name of team.
    :type name: str
    :param aad_group_id: Azure Active Directory (AAD) Group Id for the team.
    :type aad_group_id: str
    :param channel_count: The count of channels in the team.
    :type chanel_count: int
    :param member_count: The count of members in the team.
    :type member_count: int
    """

    _attribute_map = {
        "id": {"key": "id", "type": "str"},
        "name": {"key": "name", "type": "str"},
        "aad_group_id": {"key": "aadGroupId", "type": "str"},
        "channel_count": {"key": "channelCount", "type": "int"},
        "member_count": {"key": "memberCount", "type": "int"},
    }

    def __init__(self, **kwargs):
        super(TeamDetails, self).__init__(**kwargs)
        self.id = kwargs.get("id", None)
        self.name = kwargs.get("name", None)
        self.aad_group_id = kwargs.get("aad_group_id", None)
        self.channel_count = kwargs.get("channel_count", None)
        self.member_count = kwargs.get("member_count", None)


class TeamInfo(Model):
    """Describes a team.

    :param id: Unique identifier representing a team
    :type id: str
    :param name: Name of team.
    :type name: str
    """

    _attribute_map = {
        "id": {"key": "id", "type": "str"},
        "name": {"key": "name", "type": "str"},
    }

    def __init__(self, **kwargs):
        super(TeamInfo, self).__init__(**kwargs)
        self.id = kwargs.get("id", None)
        self.name = kwargs.get("name", None)


class TeamsChannelAccount(ChannelAccount):
    """Teams channel account detailing user Azure Active Directory details.

    :param id: Channel id for the user or bot on this channel (Example:
     joe@smith.com, or @joesmith or 123456)
    :type id: str
    :param name: Display friendly name
    :type name: str
    :param given_name: Given name part of the user name.
    :type given_name: str
    :param surname: Surname part of the user name.
    :type surname: str
    :param email: Email Id of the user.
    :type email: str
    :param user_principal_name: Unique user principal name
    :type user_principal_name: str
    :param tenant_id: Tenant Id of the user.
    :type tenant_id: str
    :param user_role: User Role of the user.
    :type user_role: str
    """

    _attribute_map = {
        "id": {"key": "id", "type": "str"},
        "name": {"key": "name", "type": "str"},
        "given_name": {"key": "givenName", "type": "str"},
        "surname": {"key": "surname", "type": "str"},
        "email": {"key": "email", "type": "str"},
        "userPrincipalName": {"key": "userPrincipalName", "type": "str"},
        "aad_object_id": {"key": "objectId", "type": "str"},
        "tenant_id": {"key": "tenantId", "type": "str"},
        "user_role": {"key": "userRole", "type": "str"},
    }

    def __init__(self, **kwargs):
        super(TeamsChannelAccount, self).__init__(**kwargs)
        self.given_name = kwargs.get("given_name", None)
        self.surname = kwargs.get("surname", None)
        self.email = kwargs.get("email", None)
        self.user_principal_name = kwargs.get("userPrincipalName", None)
        self.tenant_id = kwargs.get("tenantId", None)
        self.user_role = kwargs.get("userRole", None)


class TeamsPagedMembersResult(PagedMembersResult):
    """Page of members for Teams.

    :param continuation_token: Paging token
    :type continuation_token: str
    :param members: The Teams Channel Accounts.
    :type members: list[~botframework.connector.models.TeamsChannelAccount]
    """

    _attribute_map = {
        "continuation_token": {"key": "continuationToken", "type": "str"},
        "members": {"key": "members", "type": "[TeamsChannelAccount]"},
    }

    def __init__(self, **kwargs):
        super(TeamsPagedMembersResult, self).__init__(**kwargs)
        self.continuation_token = kwargs.get("continuation_token", None)
        self.members = kwargs.get("members", None)


class TeamsChannelData(Model):
    """Channel data specific to messages received in Microsoft Teams.

    :param channel: Information about the channel in which the message was
     sent
    :type channel: ~botframework.connector.teams.models.ChannelInfo
    :param event_type: Type of event.
    :type event_type: str
    :param team: Information about the team in which the message was sent
    :type team: ~botframework.connector.teams.models.TeamInfo
    :param notification: Notification settings for the message
    :type notification: ~botframework.connector.teams.models.NotificationInfo
    :param tenant: Information about the tenant in which the message was sent
    :type tenant: ~botframework.connector.teams.models.TenantInfo
    """

    _attribute_map = {
        "channel": {"key": "channel", "type": "ChannelInfo"},
        "event_type": {"key": "eventType", "type": "str"},
        "team": {"key": "team", "type": "TeamInfo"},
        "notification": {"key": "notification", "type": "NotificationInfo"},
        "tenant": {"key": "tenant", "type": "TenantInfo"},
    }

    def __init__(self, **kwargs):
        super(TeamsChannelData, self).__init__(**kwargs)
        self.channel = kwargs.get("channel", None)
        # doing camel case here since that's how the data comes in
        self.event_type = kwargs.get("event_type", None)
        self.team = kwargs.get("team", None)
        self.notification = kwargs.get("notification", None)
        self.tenant = kwargs.get("tenant", None)


class TenantInfo(Model):
    """Describes a tenant.

    :param id: Unique identifier representing a tenant
    :type id: str
    """

    _attribute_map = {
        "id": {"key": "id", "type": "str"},
    }

    def __init__(self, **kwargs):
        super(TenantInfo, self).__init__(**kwargs)
        self.id = kwargs.get("id", None)
